@@ -52,6 +52,7 @@ lishing for the web.
 __all__ = ["render"]
 
 from inspect import cleandoc as clean_indent
+
 # import os
 import re
 from textwrap import dedent
@@ -250,8 +251,7 @@ class DefinitionList(Block):
                 list.append(E.DT(term))
             for def_block in definition_block.split("\n:   "):
                 definition = E.DD()
-                self.parser.process_blocks(definition,
-                                           clean_indent(def_block))
+                self.parser.process_blocks(definition, clean_indent(def_block))
                 list.append(definition)
         return list
 
@@ -359,8 +359,8 @@ class Link(Inline):
 
     """
 
-        >>> str(render("[Example](http://example.org/)"))
-        '<p><a href="http://example.org">Example</a> </p>'
+    >>> str(render("[Example](http://example.org/)"))
+    '<p><a href="http://example.org">Example</a> </p>'
 
     """
 
@@ -385,9 +385,7 @@ class Link(Inline):
 
 class AutoLink(Inline):
 
-    """
-
-    """
+    """ """
 
     split_pattern = r"https?://\S+"
     pattern = r"(?P<uri>https?://\S+)"
@@ -401,9 +399,7 @@ class AutoLink(Inline):
 
 class WikiLink(Inline):
 
-    """
-
-    """
+    """ """
 
     pattern = r"\[\[(?P<page>.+?)\]\]"
 
@@ -416,9 +412,7 @@ class WikiLink(Inline):
 
 class Mention(Inline):
 
-    """
-
-    """
+    """ """
 
     split_pattern = r"@[A-Za-z0-9.]+"
     pattern = r"@(?P<person>[A-Za-z0-9.]+)"
@@ -436,9 +430,7 @@ class Mention(Inline):
 
 class Tag(Inline):
 
-    """
-
-    """
+    """ """
 
     split_pattern = r"#[A-Za-z0-9]+"
     pattern = r"#(?P<tag>[A-Za-z0-9]+)"
@@ -481,7 +473,8 @@ class SmartQuotes:
         dec_dashes = r"""&#8211;|&#8212;"""
 
         # Get most opening single quotes:
-        opening_single_quotes_regex = re.compile(r"""
+        opening_single_quotes_regex = re.compile(
+            r"""
                 (
                     \s          |   # a whitespace char, or
                     &nbsp;      |   # a non-breaking space entity, or
@@ -492,28 +485,40 @@ class SmartQuotes:
                 )
                 '                 # the quote
                 (?=\w)            # followed by a word character
-                """ % (dec_dashes,), re.VERBOSE)
+                """
+            % (dec_dashes,),
+            re.VERBOSE,
+        )
         text = opening_single_quotes_regex.sub(r"""\1&#8216;""", text)
 
-        closing_single_quotes_regex = re.compile(r"""
+        closing_single_quotes_regex = re.compile(
+            r"""
                 (%s)
                 '
                 (?!\s | s\b | \d)
-                """ % (close_class,), re.VERBOSE)
+                """
+            % (close_class,),
+            re.VERBOSE,
+        )
         text = closing_single_quotes_regex.sub(r"""\1&#8217;""", text)
 
-        closing_single_quotes_regex = re.compile(r"""
+        closing_single_quotes_regex = re.compile(
+            r"""
                 (%s)
                 '
                 (\s | s\b)
-                """ % (close_class,), re.VERBOSE)
+                """
+            % (close_class,),
+            re.VERBOSE,
+        )
         text = closing_single_quotes_regex.sub(r"""\1&#8217;\2""", text)
 
         # Any remaining single quotes should be opening ones:
         text = re.sub(r"""'""", r"""&#8216;""", text)
 
         # Get most opening double quotes:
-        opening_double_quotes_regex = re.compile(r"""
+        opening_double_quotes_regex = re.compile(
+            r"""
                 (
                     \s          |  # a whitespace char, or
                     &nbsp;      |  # a non-breaking space entity, or
@@ -524,21 +529,32 @@ class SmartQuotes:
                 )
                 "                  # the quote
                 (?=\w)             # followed by a word character
-                """ % (dec_dashes,), re.VERBOSE)
+                """
+            % (dec_dashes,),
+            re.VERBOSE,
+        )
         text = opening_double_quotes_regex.sub(r"""\1&#8220;""", text)
 
         # Double closing quotes:
-        closing_double_quotes_regex = re.compile(r"""
+        closing_double_quotes_regex = re.compile(
+            r"""
                 #(%s)?  # character that indicates the quote should be closing
                 "
                 (?=\s)
-                """ % (close_class,), re.VERBOSE)
+                """
+            % (close_class,),
+            re.VERBOSE,
+        )
         text = closing_double_quotes_regex.sub(r"""&#8221;""", text)
 
-        closing_double_quotes_regex = re.compile(r"""
+        closing_double_quotes_regex = re.compile(
+            r"""
                 (%s)   # character that indicates the quote should be closing
                 "
-                """ % (close_class,), re.VERBOSE)
+                """
+            % (close_class,),
+            re.VERBOSE,
+        )
         text = closing_double_quotes_regex.sub(r"""\1&#8221;""", text)
 
         # Any remaining quotes should be opening ones.
@@ -559,9 +575,7 @@ class SmartQuotes:
 
 class AutoMagnet(Inline):
 
-    """
-
-    """
+    """ """
 
     pattern = r"(?P<uri>magnet:.+?)"
 
@@ -574,10 +588,10 @@ class Reference(Inline):
 
     """
 
-        # TODO >>> str(render('''[Example][1]
-        # TODO ... 
-        # TODO ... [1]: http://example.org'''))
-        # TODO '<a href="http://example.org">Example</a>'
+    # TODO >>> str(render('''[Example][1]
+    # TODO ...
+    # TODO ... [1]: http://example.org'''))
+    # TODO '<a href="http://example.org">Example</a>'
 
     """
 
@@ -597,9 +611,7 @@ class Reference(Inline):
 
 class AutoReference:
 
-    """
-
-    """
+    """ """
 
     pattern = LINK_CONTAINER_RE
     template = '<a href="{uri}">{text}</a>'
@@ -846,7 +858,7 @@ class Strong(Inline):
 
     def parse(self, match):
         text = match.group(1)
-        return '<strong>{0}</strong>'.format(text)
+        return "<strong>{0}</strong>".format(text)
 
 
 class Em(Inline):
@@ -934,7 +946,7 @@ class InnerEmDash(Inline):
 
     def parse(self, match):
         # return '<span class="em-dash inner"><span> --- </span></span>'
-        return '&thinsp;&#x2014;&thinsp;'
+        return "&thinsp;&#x2014;&thinsp;"
 
 
 class EnDash(Inline):
@@ -994,87 +1006,88 @@ class Heart(Inline):
 #         return hyphenated
 
 
-gun_violence = {"Ammunition": "facts, evidence",
-                "armed with the facts": "well-informed",
-                "aim for": "hope to achieve",
-                "ask point blank": "ask directly",
-                "bite the bullet": "just do it",
-                "bullet points": "specifics, key points",
-                "bullet-proof": "invincible",
-                "caught in the crossfire": "caught in the middle",
-                "cheap shot": "unfair criticism",
-                "dodged a bullet": "avoided trouble",
-                "don't shoot the messenger": "not responsible",
-                "even shot": "50/50 chance",
-                "faster than a speeding bullet": "turbo speed",
-                "'Fire Away!'": "'Get started!'",
-                "firing blanks": "not succeeding",
-                "fire back": "responding quickly",
-                "going great guns": "succeeding beyond expectations",
-                "gun it": "floor it",
-                "gun shy": "reticent",
-                "gunning for someone": "planning to harm",
-                "half-cocked": "reckless",
-                "high caliber": "exceptional",
-                "hired gun": "paid specialist",
-                "hold a gun to my head": "threaten",
-                "hot shot": "show-off, braggart",
-                "in the crosshairs": "scrutinized",
-                "jumped the gun": "started too early",
-                "'Just shoot me!'": "'I give up!'",
-                "kill joy": "spoil sport",
-                "killer instinct": "ruthless",
-                "like shooting fish in a barrel": "too easy",
-                "lock, stock and barrel": "all inclusive",
-                "locked-and-loaded": "ready, prepared",
-                "magic bullet": "perfect solution",
-                "misfired": "erred",
-                "missed the mark": "imperfect, fell short",
-                "moving target": "hard to pin down",
-                "outgunned": "outmatched",
-                "on target": "accurate",
-                "point blank": "direct, precise, simple",
-                "point & shoot": "camera reference",
-                "pot shots": "jabs",
-                "pull the trigger": "get going",
-                "quick on the trigger": "rash, hasty",
-                "rapid fire": "quickly",
-                "'Ready, aim, fire!'": "'Go!'",
-                "riding shot gun": ("occupying the passenger seat",
-                                    "protecting a companion"),
-                "rifle through files": "search",
-                "'She/he is a pistol!'": "'She/he has spunk!'",
-                "shoot first, ask later": "impetuous",
-                "shoot for": "try",
-                "shoot for the moon": "set high goals",
-                "shoot from the hip": "impulsive",
-                "shoot me an email": "send me an email",
-                "shoot off your mouth": "talk recklessly",
-                "shoot out": "confrontation",
-                "shoot the breeze": "chat, visit",
-                "shot down my idea": "rejected",
-                "shot in the dark": "wild guess",
-                "shot myself in the foot": "made a mistake",
-                "silver bullet": "perfect solution",
-                "smoking gun": "proof beyond doubt",
-                "'Son of a gun!'": "'Darn!'",
-                "stick to my guns": "uncompromising",
-                "straight shooter": "frank & honest",
-                "sweating bullets": "really worried",
-                "take aim": "focus",
-                "take a shot at": "give it a try",
-                "target market": "audience segment",
-                "top gun": "recognized expert",
-                "trigger a response": "elicit a response",
-                "trigger alerts": "heads up, warnings",
-                "trigger happy": "impulsive",
-                "trip your trigger": "make you happy",
-                "under fire": "being criticized",
-                "under the gun": "feeling time pressured",
-                "whole shooting match": "in total",
-                "with guns blazing": "all-out effort",
-                "worth a shot": "worth trying",
-                "'You're killing me!'": "'You're too much!'"}
+gun_violence = {
+    "Ammunition": "facts, evidence",
+    "armed with the facts": "well-informed",
+    "aim for": "hope to achieve",
+    "ask point blank": "ask directly",
+    "bite the bullet": "just do it",
+    "bullet points": "specifics, key points",
+    "bullet-proof": "invincible",
+    "caught in the crossfire": "caught in the middle",
+    "cheap shot": "unfair criticism",
+    "dodged a bullet": "avoided trouble",
+    "don't shoot the messenger": "not responsible",
+    "even shot": "50/50 chance",
+    "faster than a speeding bullet": "turbo speed",
+    "'Fire Away!'": "'Get started!'",
+    "firing blanks": "not succeeding",
+    "fire back": "responding quickly",
+    "going great guns": "succeeding beyond expectations",
+    "gun it": "floor it",
+    "gun shy": "reticent",
+    "gunning for someone": "planning to harm",
+    "half-cocked": "reckless",
+    "high caliber": "exceptional",
+    "hired gun": "paid specialist",
+    "hold a gun to my head": "threaten",
+    "hot shot": "show-off, braggart",
+    "in the crosshairs": "scrutinized",
+    "jumped the gun": "started too early",
+    "'Just shoot me!'": "'I give up!'",
+    "kill joy": "spoil sport",
+    "killer instinct": "ruthless",
+    "like shooting fish in a barrel": "too easy",
+    "lock, stock and barrel": "all inclusive",
+    "locked-and-loaded": "ready, prepared",
+    "magic bullet": "perfect solution",
+    "misfired": "erred",
+    "missed the mark": "imperfect, fell short",
+    "moving target": "hard to pin down",
+    "outgunned": "outmatched",
+    "on target": "accurate",
+    "point blank": "direct, precise, simple",
+    "point & shoot": "camera reference",
+    "pot shots": "jabs",
+    "pull the trigger": "get going",
+    "quick on the trigger": "rash, hasty",
+    "rapid fire": "quickly",
+    "'Ready, aim, fire!'": "'Go!'",
+    "riding shot gun": ("occupying the passenger seat", "protecting a companion"),
+    "rifle through files": "search",
+    "'She/he is a pistol!'": "'She/he has spunk!'",
+    "shoot first, ask later": "impetuous",
+    "shoot for": "try",
+    "shoot for the moon": "set high goals",
+    "shoot from the hip": "impulsive",
+    "shoot me an email": "send me an email",
+    "shoot off your mouth": "talk recklessly",
+    "shoot out": "confrontation",
+    "shoot the breeze": "chat, visit",
+    "shot down my idea": "rejected",
+    "shot in the dark": "wild guess",
+    "shot myself in the foot": "made a mistake",
+    "silver bullet": "perfect solution",
+    "smoking gun": "proof beyond doubt",
+    "'Son of a gun!'": "'Darn!'",
+    "stick to my guns": "uncompromising",
+    "straight shooter": "frank & honest",
+    "sweating bullets": "really worried",
+    "take aim": "focus",
+    "take a shot at": "give it a try",
+    "target market": "audience segment",
+    "top gun": "recognized expert",
+    "trigger a response": "elicit a response",
+    "trigger alerts": "heads up, warnings",
+    "trigger happy": "impulsive",
+    "trip your trigger": "make you happy",
+    "under fire": "being criticized",
+    "under the gun": "feeling time pressured",
+    "whole shooting match": "in total",
+    "with guns blazing": "all-out effort",
+    "worth a shot": "worth trying",
+    "'You're killing me!'": "'You're too much!'",
+}
 
 # ---- PARSER.PY --------------------------------------------------------------
 
@@ -1084,35 +1097,51 @@ import lxml.html
 import lxml.html.builder as E  # noqa
 import regex as re
 
-block_elements = [HTML, Pre, HashHeading, ReSTHeading,
-                  HorizontalRule, OrderedList, UnorderedList,
-                  DefinitionList, Blockquote, Paragraph]
+block_elements = [
+    HTML,
+    Pre,
+    HashHeading,
+    ReSTHeading,
+    HorizontalRule,
+    OrderedList,
+    UnorderedList,
+    DefinitionList,
+    Blockquote,
+    Paragraph,
+]
 
 inline_elements = [  # "SmartQuotes",
-                   # # "SmallCapitals",
-                   # # "LicenseLink", "LicenseReference",
-                   # #   "LicenseAutoReference",
-                   # # "OrgLink", "OrgReference", "OrgAutoReference",
-                   # # "PersonLink", "PersonReference", "PersonAutoReference",
-                   ImageLink, ImageReference, ImageAutoReference,
-                   # "WikiLink",
-                   # "Reference", "AutoReference",
-                   # "AutoMagnet",
-                   # "Section", "Widow",
-                   StrongEm, Strong, Em, Small, Code,
-
-                   Link, AutoLink, WikiLink,
-                   Mention, Tag,
-
-                   # "Ampersand", "Copyright", "Ellipsis", "LigatureAE",
-                   #    "Heart",
-                   # "QuotationDash", "DblEmDash",
-                   # "InnerEmDash",
-                   EmDash,
-                   # "InnerEnDash",
-                   EnDash,
-                   # # "Hyphenate",
-                   ]
+    # # "SmallCapitals",
+    # # "LicenseLink", "LicenseReference",
+    # #   "LicenseAutoReference",
+    # # "OrgLink", "OrgReference", "OrgAutoReference",
+    # # "PersonLink", "PersonReference", "PersonAutoReference",
+    ImageLink,
+    ImageReference,
+    ImageAutoReference,
+    # "WikiLink",
+    # "Reference", "AutoReference",
+    # "AutoMagnet",
+    # "Section", "Widow",
+    StrongEm,
+    Strong,
+    Em,
+    Small,
+    Code,
+    Link,
+    AutoLink,
+    WikiLink,
+    Mention,
+    Tag,
+    # "Ampersand", "Copyright", "Ellipsis", "LigatureAE",
+    #    "Heart",
+    # "QuotationDash", "DblEmDash",
+    # "InnerEmDash",
+    EmDash,
+    # "InnerEnDash",
+    EnDash,
+    # # "Hyphenate",
+]
 
 _LT = "%!lt!%"
 _GT = "%!gt!%"
@@ -1160,6 +1189,7 @@ def postprocess_lga(text):
 def preprocess_script_style_pre_textarea(mahna):
     def esc(m):
         return m.group(0).replace("\n", "%!nl!%")
+
     mahna = re.sub(r"(?s)<script.*?>(.*?)</script>", esc, mahna)
     mahna = re.sub(r"(?s)<style.*?>(.*?)</style>", esc, mahna)
     mahna = re.sub(r"(?s)<pre.*?>(.*?)</pre>", esc, mahna)
@@ -1174,6 +1204,7 @@ def preprocess_inline_code(mahna):
 
     def escape_match_handler(m):
         return "<code>{0}</code>".format(preprocess_lga(m.group(0).strip("`")))
+
     return re.sub(r"`(.*?)`", escape_match_handler, mahna)
 
 
@@ -1260,8 +1291,9 @@ class Document:
 
         self.process_abbreviations(dom)
 
-        output = lxml.html.tostring(dom, pretty_print=True,
-                                    encoding="utf-8").decode("utf-8")
+        output = lxml.html.tostring(dom, pretty_print=True, encoding="utf-8").decode(
+            "utf-8"
+        )
         output = lxml.html.tostring(dom, pretty_print=True).decode("utf-8")
 
         output = postprocess_lga(output)
@@ -1280,17 +1312,17 @@ class Document:
                 if level < curr:
                     return section
                 if level == curr:
-                    section.append(E.LI(E.A(text, href="#" + id),
-                                        tocify(_toc[i:], curr + 1)))
+                    section.append(
+                        E.LI(E.A(text, href="#" + id), tocify(_toc[i:], curr + 1))
+                    )
             return section
 
         toc = tocify(self.toc, top_heading_level + 1)
         toc.set("id", "toc")  # toc["id"] = "toc"
-        for ol in toc.cssselect("ol"):    # XXX two words, rhymes with bucket
+        for ol in toc.cssselect("ol"):  # XXX two words, rhymes with bucket
             if ol.getparent() is not None and not len(ol):
                 ol.drop_tag()
-        output = output.replace("<p>[Contents] </p>",
-                                str(lxml.html.tostring(toc)))
+        output = output.replace("<p>[Contents] </p>", str(lxml.html.tostring(toc)))
 
         # if options and options.document:
         #     try:
