@@ -71,22 +71,18 @@ def splitline(text):
         ('', '')
 
     """
-    before, partition, after = text.partition('\n')
+    before, partition, after = text.partition("\n")
     return before + partition, after
 
 
 class Node:
 
-    """
-
-    """
+    """ """
 
 
 class DefWith(Node):
 
-    """
-
-    """
+    """ """
 
     def __init__(self, defwith, suite):
         if defwith:
@@ -102,8 +98,9 @@ class DefWith(Node):
         self.suite = suite
 
     def emit(self, indent):
-        return "\n".join((self.defwith, self.suite.emit(indent + _indent),
-                          "    return self"))
+        return "\n".join(
+            (self.defwith, self.suite.emit(indent + _indent), "    return self")
+        )
 
     def __repr__(self):
         return "<defwith: {0}, {1}>".format(self.defwith, self.suite)
@@ -111,9 +108,7 @@ class DefWith(Node):
 
 class Var(Node):
 
-    """
-
-    """
+    """ """
 
     def __init__(self, name, value):
         self.name = name
@@ -128,9 +123,7 @@ class Var(Node):
 
 class Text(Node):
 
-    """
-
-    """
+    """ """
 
     def __init__(self, value):
         self.value = value
@@ -144,9 +137,7 @@ class Text(Node):
 
 class Expression:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, value, escape=True):
         self.value = value.strip()
@@ -167,9 +158,7 @@ class Expression:
 
 class Assignment:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, code):
         self.code = code
@@ -183,9 +172,7 @@ class Assignment:
 
 class Line:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, nodes):
         self.nodes = nodes
@@ -202,9 +189,7 @@ class Line:
 
 class Code:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, stmt, block, begin_indent=""):
         # compensate one line for $code:
@@ -220,9 +205,7 @@ class Code:
 
 class Statement:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, stmt):
         self.stmt = stmt
@@ -256,9 +239,7 @@ class Suite:
 
 class Block:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, stmt, block, begin_indent=""):
         self.stmt = stmt
@@ -276,9 +257,7 @@ class Block:
 
 class Def(Block):
 
-    """
-
-    """
+    """ """
 
     def __init__(self, *a, **kw):
         Block.__init__(self, *a, **kw)
@@ -312,22 +291,19 @@ class Elif(Block):
 
 class For(Block):
 
-    """
-
-    """
+    """ """
 
     def __init__(self, stmt, block, begin_indent=""):
         self.original_stmt = stmt
         tok = Tokenizer(stmt)
         tok.consume_till("in")
-        a = stmt[:tok.index]    # for i in
-        b = stmt[tok.index:-1]    # rest of for stmt excluding :
+        a = stmt[: tok.index]  # for i in
+        b = stmt[tok.index : -1]  # rest of for stmt excluding :
         stmt = a + " loop.setup(" + b.strip() + "):"
         Block.__init__(self, stmt, block, begin_indent)
 
     def __repr__(self):
-        return "<block: {0}, {1}>".format(repr(self.original_stmt),
-                                          repr(self.suite))
+        return "<block: {0}, {1}>".format(repr(self.original_stmt), repr(self.suite))
 
 
 class ForLoop:
@@ -403,14 +379,18 @@ class ForLoopContext:
 
 class Parser:
 
-    """
-
-    """
+    """ """
 
     keywords = ("pass", "break", "continue", "return")
-    statement_nodes = {"for": For, "while": Block,
-                       "if": If, "elif": Elif, "else": Else,
-                       "def": Def, "code": Code}
+    statement_nodes = {
+        "for": For,
+        "while": Block,
+        "if": If,
+        "elif": Elif,
+        "else": Else,
+        "def": Def,
+        "code": Code,
+    }
 
     def __init__(self):
         self.statement_nodes = self.statement_nodes
@@ -426,7 +406,7 @@ class Parser:
     def read_defwith(self, text):
         if text.startswith("$def with"):
             defwith, text = splitline(text)
-            defwith = defwith[1:].strip()    # strip $ and spaces
+            defwith = defwith[1:].strip()  # strip $ and spaces
             return defwith, text
         else:
             return "", text
@@ -449,7 +429,7 @@ class Parser:
         """
         if text.lstrip(" ").startswith("$"):
             index = text.index("$")
-            begin_indent, text2 = text[:index], text[index + 1:]
+            begin_indent, text2 = text[:index], text[index + 1 :]
             ahead = self.python_lookahead(text2)
             if ahead == "var":
                 return self.read_var(text2)
@@ -482,17 +462,17 @@ class Parser:
         sep = tokens[2]
         value = line.split(sep, 1)[1].strip()
         if sep == "=":
-            pass    # no need to process value
+            pass  # no need to process value
         elif sep == ":":
             # FIXME hack for backward-compatability
-            if tokens[3] == "\n":    # multi-line var statement
+            if tokens[3] == "\n":  # multi-line var statement
                 block, text = self.read_indented_block(text, "        ")
                 lines = [self.readline(x)[0] for x in block.splitlines()]
                 _nodes = []
                 for x in lines:
                     _nodes.extend(x.nodes)
                     _nodes.append(Text("\n"))
-            else:    # single-line var statement
+            else:  # single-line var statement
                 linenode, _ = self.readline(value)
                 _nodes = linenode.nodes
             parts = [node.emit("") for node in _nodes]
@@ -555,11 +535,11 @@ class Parser:
         """
         if text.startswith("$$"):
             return Text("$"), text[2:]
-        elif text.startswith("$#"):    # comment
+        elif text.startswith("$#"):  # comment
             line, text = splitline(text)
             return Text("\n"), text
         elif text.startswith("$"):
-            text = text[1:]    # strip $
+            text = text[1:]  # strip $
             if text.startswith(":"):
                 escape = False
                 text = text[1:]  # strip `:`
@@ -639,7 +619,7 @@ class Parser:
             tokens.lookahead()
             # XXX dot = tokens.lookahead()
             if tokens.lookahead2().type == token.NAME:
-                next(tokens)    # XXX can remove comment? -- # consume dot
+                next(tokens)  # XXX can remove comment? -- # consume dot
                 identifier()
                 extended_expr()
 
@@ -672,8 +652,7 @@ class Parser:
                 if end is not None and end != t.begin:
                     _, x1 = end
                     _, x2 = t.begin
-                    yield Token(type=-1, value=text[x1:x2],
-                                begin=end, end=t.begin)
+                    yield Token(type=-1, value=text[x1:x2], begin=end, end=t.begin)
                 end = t.end
                 yield t
 
@@ -777,7 +756,7 @@ class Parser:
             if line.strip() == "":
                 block += "\n"
             elif line.startswith(indent):
-                block += line[len(indent):]
+                block += line[len(indent) :]
             else:
                 break
             text = text2
@@ -794,7 +773,7 @@ class Parser:
         """
         tok = Tokenizer(text)
         tok.consume_till(":")
-        return text[:tok.index], text[tok.index:]
+        return text[: tok.index], text[tok.index :]
 
     def read_block_section(self, text, begin_indent=""):
         r"""
@@ -817,13 +796,15 @@ class Parser:
         if line.strip():
             block = line.lstrip()
         else:
+
             def find_indent(text):
                 rx = re.compile("    +")
                 match = rx.match(text)
                 first_indent = match and match.group(0)
                 return first_indent or ""
+
             # find the indentation of the block by looking at the first line
-            first_indent = find_indent(text)[len(begin_indent):]
+            first_indent = find_indent(text)[len(begin_indent) :]
             # TODO fix this special case
             if keyword == "code":
                 indent = begin_indent + first_indent
