@@ -30,8 +30,17 @@ import hstspreload
 
 from . import publicsuffix
 
-__all__ = ["parse", "supported_schemes", "HTTPURI", "HTTPSURI", "WSURI",
-           "WSSURI", "DataURI", "JavascriptURI", "MagnetURI"]
+__all__ = [
+    "parse",
+    "supported_schemes",
+    "HTTPURI",
+    "HTTPSURI",
+    "WSURI",
+    "WSSURI",
+    "DataURI",
+    "JavascriptURI",
+    "MagnetURI",
+]
 
 
 def parse(uri, secure=True) -> URI:
@@ -121,8 +130,7 @@ class URI:
             return self.__hash
         except AttributeError:
             pass
-        self.__hash = int(hashlib.sha1(bytes(self.normalized,
-                                             "utf-8")).hexdigest(), 16)
+        self.__hash = int(hashlib.sha1(bytes(self.normalized, "utf-8")).hexdigest(), 16)
         return self.__hash
 
     def __repr__(self):
@@ -160,8 +168,11 @@ class HTTPURI(URI):
         if query is None:
             query = {}
         query_string = urllib.parse.urlencode(query, doseq=True)
-        return cls(urllib.parse.urlunsplit((cls.__name__.lower(), netloc,
-                                            path, query_string, fragment)))
+        return cls(
+            urllib.parse.urlunsplit(
+                (cls.__name__.lower(), netloc, path, query_string, fragment)
+            )
+        )
 
     @property
     def dict_items(self):
@@ -170,7 +181,7 @@ class HTTPURI(URI):
     @property
     def minimized(self):
         uri = self.normalized
-        uri = uri[len(self.scheme) + 3:]
+        uri = uri[len(self.scheme) + 3 :]
         if uri.startswith("www."):
             uri = uri[4:]
         # FIXME strip trail slash on path not fragment
@@ -179,8 +190,13 @@ class HTTPURI(URI):
     @property
     def normalized(self):
         query = urllib.parse.urlencode(self.query, doseq=True)
-        normalized_parts = ("https" if self.is_secure else "http",
-                            self.netloc, self.path, query, self.fragment)
+        normalized_parts = (
+            "https" if self.is_secure else "http",
+            self.netloc,
+            self.path,
+            query,
+            self.fragment,
+        )
         normalized = urllib.parse.urlunsplit(normalized_parts)
         # XXX if self.is_relative:
         # XXX     normalized = "/" + normalized
@@ -219,8 +235,9 @@ class HTTPURI(URI):
             self.netloc += self.host
             if self.port != 80:
                 self.netloc += ":" + str(self.port)
-            self.subdomain, self.domain, self.suffix = \
-                publicsuffix.split(parts.hostname)
+            self.subdomain, self.domain, self.suffix = publicsuffix.split(
+                parts.hostname
+            )
         self.path = self._normalize_path(parts.path).lstrip("/")
         self.raw_query = self._normalize_query(parts.query)
         self.query = urllib.parse.parse_qs(self.raw_query)
@@ -285,8 +302,15 @@ class HTTPURI(URI):
     def _normalize_query(self, query):
         # TODO %3a to %3A
         # TODO %7E to ~
-        args = ["=".join([urllib.parse.quote(clean(t), "~:/?#[]@!$'()*+,;=")
-                for t in q.split("=", 1)]) for q in query.split("&")]
+        args = [
+            "=".join(
+                [
+                    urllib.parse.quote(clean(t), "~:/?#[]@!$'()*+,;=")
+                    for t in q.split("=", 1)
+                ]
+            )
+            for q in query.split("&")
+        ]
         return "&".join(args)
 
     def _normalize_fragment(self, fragment):
@@ -377,8 +401,7 @@ class DataURI(URI):
 
     """
 
-    def __init__(self, data, encoded=False,
-                 mime_type="text/plain", charset="US-ASCII"):
+    def __init__(self, data, encoded=False, mime_type="text/plain", charset="US-ASCII"):
         self.data = data
         self.encoded = encoded
         self.mime_type = mime_type
@@ -461,9 +484,7 @@ class JavascriptURI(URI):
 
     @classmethod
     def from_identifier(cls, identifier):
-        """
-
-        """
+        """ """
         print(identifier)
         return cls()
 
