@@ -42,7 +42,7 @@ def split(hostname):
     _suffixes.lookup(hits, 1, parts)
     for i, what in enumerate(hits):
         if what is not None and what == 0:
-            return Domain(".".join(parts[:i]), parts[i], ".".join(parts[i+1:]))
+            return Domain(".".join(parts[:i]), parts[i], ".".join(parts[i + 1 :]))
 
 
 def _initialize():
@@ -58,14 +58,16 @@ class _PublicSuffixList:
     """
 
     def __init__(self):
-        input_path = pkg_resources.resource_filename("understory.uri",
-                                                     "public_suffix_list.dat")
+        input_path = pkg_resources.resource_filename(
+            "understory.uri", "public_suffix_list.dat"
+        )
         try:
             with codecs.open(input_path, "r", "utf8") as fp:
                 self._build_structure(fp)
         except FileNotFoundError:
-            res = requests.get("https://publicsuffix.org/list/"
-                               "public_suffix_list.dat")
+            res = requests.get(
+                "https://publicsuffix.org/list/" "public_suffix_list.dat"
+            )
             with codecs.open(input_path, "w", "utf8") as fp:
                 fp.write(res.text)
             with codecs.open(input_path, "r", "utf8") as fp:
@@ -84,7 +86,7 @@ class _PublicSuffixList:
             for name in ("*", parts[-depth]):
                 child = children.get(name, None)
                 if child is not None:
-                    self.lookup(matches, depth+1, parts, child)
+                    self.lookup(matches, depth + 1, parts, child)
 
     def _build_structure(self, fp):
         root = [0]
@@ -120,5 +122,4 @@ class _PublicSuffixList:
     def _simplify(self, node):
         if len(node) == 1:
             return node[0]
-        return (node[0], dict((k, self._simplify(v)) for
-                              (k, v) in node[1].items()))
+        return (node[0], dict((k, self._simplify(v)) for (k, v) in node[1].items()))
