@@ -64,8 +64,9 @@ class Micropub:
         except KeyError:
             if self.channel:
                 properties["channel"] = self.channel
-        location, links = web.micropub.send(properties, endpoint=self.endpoint,
-                                            h=self.type, token=self.token)
+        location, links = web.micropub.send(
+            properties, endpoint=self.endpoint, h=self.type, token=self.token
+        )
         print("Location:", location)
         print("Links:", links)
         return 0
@@ -92,11 +93,17 @@ class Braidpub:
 
     def run(self, stdin, log):
         patch_body = stdin.read()
-        web.put(self.uri, headers={"Patches": "1"}, data=textwrap.dedent(f"""
+        web.put(
+            self.uri,
+            headers={"Patches": "1"},
+            data=textwrap.dedent(
+                f"""
             content-length: {len(patch_body)}
             content-range: {self.range}
 
-            {patch_body}"""))
+            {patch_body}"""
+            ),
+        )
         return 0
 
 
