@@ -24,14 +24,23 @@ from understory import sql
 from understory import uri
 from understory import web
 
-__all__ = ["post", "get", "put", "delete",
-           "parse", "browser", "firefox", "cache", "discover_link", "download"]
+__all__ = [
+    "post",
+    "get",
+    "put",
+    "delete",
+    "parse",
+    "browser",
+    "firefox",
+    "cache",
+    "discover_link",
+    "download",
+]
 
 displays = []
 browsers = []
 
-tor_proxies = {"http": "socks5h://localhost:9050",
-               "https": "socks5h://localhost:9050"}
+tor_proxies = {"http": "socks5h://localhost:9050", "https": "socks5h://localhost:9050"}
 
 
 def discover_link(target, name):
@@ -84,7 +93,7 @@ def download(url, filepath, chunk_size=1024):
     return response
 
 
-def request(method, url, **kwargs):
+def request(method, url, session=None, **kwargs):
     """
     Return the response to dereferencing given `url` using given `method`.
 
@@ -98,17 +107,17 @@ def request(method, url, **kwargs):
     if url.suffix == "onion":
         kwargs["proxies"] = tor_proxies
         preferred = "http"
-    try:
-        response = requests.request(method, f"{preferred}://{url.minimized}",
-                                    verify=False, **kwargs)
-    except (requests.exceptions.SSLError, requests.exceptions.ConnectionError):
-        if url.suffix != "onion":
-            try:
-                response = requests.request(method, f"http://{url.minimized}",
-                                            **kwargs)
-            except (requests.exceptions.SSLError,
-                    requests.exceptions.ConnectionError):
-                raise RequestFailed()
+    context = session if session else requests
+    # try:
+    #     response = context.request(
+    #         method, f"{preferred}://{url.minimized}", verify=False, **kwargs
+    #     )
+    # except (requests.exceptions.SSLError, requests.exceptions.ConnectionError):
+    #     if url.suffix != "onion":
+    #         try:
+    response = context.request(method, f"http://{url.minimized}", **kwargs)
+    #         except (requests.exceptions.SSLError, requests.exceptions.ConnectionError):
+    #             raise RequestFailed()
     return response
 
 
@@ -137,7 +146,6 @@ def delete(url, **kwargs):
 
 
 class Cache:
-
     def __init__(self, domain=None, db=None):
         self.cache = {}
         if domain:
@@ -146,8 +154,9 @@ class Cache:
             self.db = db
         else:
             self.db = sql.db("cache.db")
-        self.db.define(cache="""url TEXT UNIQUE, html TEXT,
-                                headers JSON, data JSON""")
+        self.db.define(
+            "cache", url="TEXT UNIQUE", html="TEXT", headers="JSON", data="JSON"
+        )
 
     def format_url(self, url):
         try:
@@ -161,14 +170,22 @@ class Cache:
         resource = get(url)
         self.cache[url] = resource
         try:
-            self.db.insert("cache", url=url, html=resource.text,
-                           headers=dict(resource.headers),
-                           data=resource.mf2json.data)
+            self.db.insert(
+                "cache",
+                url=url,
+                html=resource.text,
+                headers=dict(resource.headers),
+                data=resource.mf2json.data,
+            )
         except self.db.IntegrityError:
-            self.db.update("cache", html=resource.text,
-                           headers=dict(resource.headers),
-                           data=resource.mf2json.data, where="url = ?",
-                           vals=[url])
+            self.db.update(
+                "cache",
+                html=resource.text,
+                headers=dict(resource.headers),
+                data=resource.mf2json.data,
+                where="url = ?",
+                vals=[url],
+            )
         except AttributeError:
             pass
         return resource
@@ -180,8 +197,7 @@ class Cache:
         except KeyError:
             try:
                 url = self.format_url(resource_url)
-                resource_data = self.db.select("cache", where="url = ?",
-                                               vals=[url])[0]
+                resource_data = self.db.select("cache", where="url = ?", vals=[url])[0]
                 resource = Transaction(url, fetch=False)
                 resource.headers = resource_data["headers"]  # TODO case-insen
                 resource.text = resource_data["html"]
@@ -205,12 +221,13 @@ cache = Cache
 class Transaction:
     """."""
 
-    def __init__(self, url, method="get", fetch=True, **kwargs):
+    def __init__(self, url, method="get", fetch=True, session=None, **kwargs):
         self.url = str(uri.parse(str(url)))
         if fetch:
             # XXX handler = getattr(requests, method)
             # XXX self.response = handler(apply_dns(self.url), **kwargs)
-            self.response = request(method, self.url, **kwargs)
+            self.response = request(method, self.url, session=session, **kwargs)
+            self.status = self.response.status_code
             self.text = self.response.text
             self.headers = self.response.headers
 
@@ -241,27 +258,22 @@ class Transaction:
 
     @property
     def card(self):
-        return Semantics(mf.representative_card(self.mf2json.data,
-                                                source_url=self.url))
+        return Semantics(mf.representative_card(self.mf2json.data, source_url=self.url))
 
     @property
     def feed(self):
-        return Semantics(mf.interpret_feed(self.mf2json.data,
-                                           source_url=self.url))
+        return Semantics(mf.interpret_feed(self.mf2json.data, source_url=self.url))
 
     @property
     def entry(self):
-        return Semantics(mf.interpret_entry(self.mf2json.data,
-                                            source_url=self.url))
+        return Semantics(mf.interpret_entry(self.mf2json.data, source_url=self.url))
 
     @property
     def event(self):
-        return Semantics(mf.interpret_event(self.mf2json.data,
-                                            source_url=self.url))
+        return Semantics(mf.interpret_event(self.mf2json.data, source_url=self.url))
 
     def mention(self, *target_urls):
-        return Semantics(mf.interpret_comment(self.mf2json.data,
-                                              self.url, target_urls))
+        return Semantics(mf.interpret_comment(self.mf2json.data, self.url, target_urls))
 
     # @property
     # def jf2(self):
@@ -270,7 +282,6 @@ class Transaction:
 
 
 class Semantics:
-
     def __init__(self, data):
         self.data = data
 
@@ -282,8 +293,7 @@ class Semantics:
         # XXX return json.dumps(self.data, indent=2)
 
     def _repr_html_(self):
-        return solarized.highlight(JSONEncoder(indent=2).encode(self.data),
-                                   ".json")
+        return solarized.highlight(JSONEncoder(indent=2).encode(self.data), ".json")
         # XXX return solarized.highlight(json.dumps(self.data, indent=2),
         # ".json")
 
@@ -292,7 +302,6 @@ class Semantics:
 
 
 class JSONEncoder(json.JSONEncoder):
-
     def default(self, obj):
         if isinstance(obj, uri.URI):
             return str(obj)
@@ -311,14 +320,11 @@ def apply_dns(url):
         return url
     url = uri.parse(url)
     if url.host == "alice.example":
-        url = str(url).replace("http://alice.example",
-                               "http://127.0.0.1:8080")
+        url = str(url).replace("http://alice.example", "http://127.0.0.1:8080")
     elif url.host == "bob.example":
-        url = str(url).replace("http://bob.example",
-                               "http://127.0.0.1:8081")
+        url = str(url).replace("http://bob.example", "http://127.0.0.1:8081")
     elif url.host == "hello.example":
-        url = str(url).replace("http://hello.example",
-                               "http://127.0.0.1:8082")
+        url = str(url).replace("http://hello.example", "http://127.0.0.1:8082")
     else:
         url = str(url)
     return url
@@ -328,14 +334,11 @@ def unapply_dns(url):
     url = uri.parse(url)
     if url.host == "127.0.0.1":
         if url.port == 8080:
-            url = str(url).replace("http://127.0.0.1:8080",
-                                   "http://alice.example")
+            url = str(url).replace("http://127.0.0.1:8080", "http://alice.example")
         elif url.port == 8081:
-            url = str(url).replace("http://127.0.0.1:8081",
-                                   "http://bob.example")
+            url = str(url).replace("http://127.0.0.1:8081", "http://bob.example")
         elif url.port == 8082:
-            url = str(url).replace("http://127.0.0.1:8082",
-                                   "http://hello.example")
+            url = str(url).replace("http://127.0.0.1:8082", "http://hello.example")
     else:
         url = str(url)
     return url
@@ -364,7 +367,6 @@ class Document:
 
 
 class Element:
-
     def __init__(self, element):
         self.element = element
 
@@ -397,80 +399,16 @@ def _make_element(html):
 
 
 class Browser:
+    """"""
 
     def __init__(self, apps=None):
-        self.apps = apps
+        self.session = requests.Session()
 
-    def get(self, url, data=None):
-        """GET resource at `url`."""
-        return self.handle("GET", url, data)
+    def get(self, url, **kwargs):
+        return Transaction(url, "GET", session=self.session, **kwargs)
 
-    def put(self, url, data):
-        """PUT `data` to `url`."""
-        return self.handle("PUT", url, data)
-
-    def delete(self, url):
-        """DELETE resource at `url`."""
-        return self.handle("DELETE", url)
-
-    def post(self, url, data):
-        """POST `data` to `url`."""
-        return self.handle("POST", url, data)
-
-    def handle(self, method, url, data=None):
-        """
-        Handle a request to the outside web or a local WSGI app.
-
-        Use `requests` to reach the world wide web. Otherwise communicate
-        directly with WSGI apps in-process.
-
-        """
-        # TODO remove extraneous WSGI items
-        url = str(url)
-        if url.startswith(("http://", "https://")):
-            return getattr(requests, method.lower())(url)
-        response = []
-        hostname, _, path = url.partition("/")
-        path, _, query = path.partition("?")
-        app = self.apps[hostname]
-        if data:
-            wsgi_input = io.StringIO(json.dumps(data))
-        else:
-            wsgi_input = open("/dev/null")
-        env = {'HTTP_HOST': hostname,
-               'HTTP_CONNECTION': 'keep-alive',
-               'HTTP_ACCEPT': 'image/png,image/*;q=0.8,*/*;q=0.5',
-               'HTTP_USER_AGENT': 'Mozilla/5.0 (X11; Ubuntu; Linux i686; '
-                                  'rv:21.0) Gecko/20100101 Firefox/21.0',
-               'HTTP_COOKIE': 'session=99f81fd1f5e4c13b724043336f75'
-                              'e81ee51d806979220cc8cebe51bc9d0de292',
-               'HTTP_ACCEPT_LANGUAGE': 'en-US,en;q=0.5',
-               'HTTP_ACCEPT_ENCODING': 'gzip, deflate',
-               'PATH_INFO': f"/{path}",
-               'QUERY_STRING': query,
-               # XXX 'RAW_URI': f"/{path}",
-               'REMOTE_ADDR': '127.0.0.1',
-               # XXX 'REMOTE_PORT': '44612',
-               'REQUEST_METHOD': method,
-               # XXX 'SCRIPT_NAME': '',
-               'SERVER_PROTOCOL': 'HTTP/1.1',
-               'SERVER_SOFTWARE': 'gunicorn/0.17.4',
-               # XXX 'SERVER_NAME': 'localhost',
-               # XXX 'SERVER_PORT': '22739',
-               'wsgi.input': wsgi_input,
-               'wsgi.url_scheme': 'http'}
-
-        def start_response(status, headers):
-            response.append(status)
-            response.append(headers)
-
-        response.append(app(env, start_response))
-
-        transaction = Transaction(url, fetch=False)
-        transaction.status = web.tx.response.status
-        transaction.headers = web.tx.response.headers
-        transaction.text = web.tx.response.body
-        return transaction
+    def post(self, url, **kwargs):
+        return Transaction(url, "POST", session=self.session, **kwargs)
 
 
 browser = Browser
@@ -488,12 +426,13 @@ class Firefox:
             display.start()
             displays.append(display)
         profile = webdriver.FirefoxProfile()
-        profile.add_extension(extension="/home/gaea/canopy/var/identities/"
-                                        "6c189616-4fe1-4f3f-84dc-c4a13ee9b155/"
-                                        "asteria/asteria-dev.xpi")
+        profile.add_extension(
+            extension="/home/gaea/canopy/var/identities/"
+            "6c189616-4fe1-4f3f-84dc-c4a13ee9b155/"
+            "asteria/asteria-dev.xpi"
+        )
         binary = "/home/gaea/firefox/firefox-bin"
-        self.browser = webdriver.Firefox(firefox_profile=profile,
-                                         firefox_binary=binary)
+        self.browser = webdriver.Firefox(firefox_profile=profile, firefox_binary=binary)
         count = len(browsers)
         browsers.append(self)
         self._top = 0
@@ -523,8 +462,7 @@ class Firefox:
         self._update_window()
 
     def _update_window(self):
-        self.browser.set_window_rect(self._left, self._top,
-                                     self._width, self._height)
+        self.browser.set_window_rect(self._left, self._top, self._width, self._height)
 
     def go(self, *args, wait=0):
         if len(args) == 1:
@@ -540,7 +478,7 @@ class Firefox:
 
     def wait(self, *conditions, duration=20):
         for condition in conditions:
-            time.sleep(.1)
+            time.sleep(0.1)
             wait = WebDriverWait(self.browser, duration)
             wait.until(condition)
 
@@ -573,8 +511,7 @@ class Firefox:
         self.shot_id += 1
         filename = f"{self.name}-{self.shot_id}.png"
         placement = browsers.index(self)
-        coords = (1024 * placement, 0,
-                  1024 * (placement + 1), 768)
+        coords = (1024 * placement, 0, 1024 * (placement + 1), 768)
         # import sh
         # sh.Command("import")("-screen", "-window", "root", filename)
         # time.sleep(2)
