@@ -12,8 +12,11 @@ a Pythonic API.
 
 """
 
+from __future__ import annotations
+
 from base64 import b64encode, b64decode
 import collections
+
 # import errno
 import getpass
 import hashlib
@@ -46,63 +49,152 @@ from understory import sql
 from understory import term  # noqa NOTE to colorize print()
 
 from ..agent import parse, apply_dns, cache
-from ..response import (Status,  # noqa
-                        OK, Created, Accepted, NoContent, MultiStatus,
-                        Subscription,
-                        Found, SeeOther, PermanentRedirect,
-                        BadRequest, Unauthorized, Forbidden, NotFound,
-                        MethodNotAllowed, Conflict, Gone)
+from ..response import (
+    Status,  # noqa
+    OK,
+    Created,
+    Accepted,
+    NoContent,
+    MultiStatus,
+    Subscription,
+    Found,
+    SeeOther,
+    PermanentRedirect,
+    BadRequest,
+    Unauthorized,
+    Forbidden,
+    NotFound,
+    MethodNotAllowed,
+    Conflict,
+    Gone,
+)
 from .letsencrypt import generate_cert
 from .newmath import nbencode, nbdecode, nbrandom, nb60_re
 from .passphrases import generate_passphrase, verify_passphrase
 from .util import tx, header, json, JSONEncoder, shift_headings
 
 import warnings  # mf2py's beautifulsoup's unspecified parser -- force lxml?
+
 warnings.simplefilter("ignore")
 
 random = secrets.SystemRandom()
 
-__all__ = ["application", "serve", "anti_csrf", "form", "secure_form",
-           "get_nonce", "get_token", "best_match", "sessions",
-           "require_auth", "tx", "kv", "header",
-           "Application", "Resource", "nbencode", "nbdecode", "nbrandom",
-           "Template", "config_templates", "generate_cert",
-           "get_integrity_factory", "utcnow", "JSONEncoder",
-           "default_session_timeout", "textslug", "get_host_hash",
-           "config_servers", "b64encode", "b64decode", "timeslug",
-           "enqueue", "run_redis", "kill_redis", "get_apps", "nb60_re",
-           "generate_passphrase", "verify_passphrase", "sleep", "random",
-           "session_table_sql", "resume_session", "add_job_tables"]
+__all__ = [
+    "application",
+    "serve",
+    "anti_csrf",
+    "form",
+    "secure_form",
+    "get_nonce",
+    "get_token",
+    "best_match",
+    "sessions",
+    "require_auth",
+    "tx",
+    "kv",
+    "header",
+    "Application",
+    "Resource",
+    "nbencode",
+    "nbdecode",
+    "nbrandom",
+    "Template",
+    "config_templates",
+    "generate_cert",
+    "get_integrity_factory",
+    "utcnow",
+    "JSONEncoder",
+    "default_session_timeout",
+    "textslug",
+    "get_host_hash",
+    "config_servers",
+    "b64encode",
+    "b64decode",
+    "timeslug",
+    "enqueue",
+    "run_redis",
+    "kill_redis",
+    "get_apps",
+    "nb60_re",
+    "generate_passphrase",
+    "verify_passphrase",
+    "sleep",
+    "random",
+    "session_table_sql",
+    "resume_session",
+    "add_job_tables",
+]
 
-kvdb = kv.db("web", ":", {"auth:secret": "string",
-                          "auth:nonces": "set",
-                          "reload-lock": "string",
-                          "sessions:{session_id}": "string",
-                          "sessions:{session_id}:data": "string"},
-             session_id=r"[a-z0-9]{,65}")
+kvdb = kv.db(
+    "web",
+    ":",
+    {
+        "auth:secret": "string",
+        "auth:nonces": "set",
+        "reload-lock": "string",
+        "sessions:{session_id}": "string",
+        "sessions:{session_id}:data": "string",
+    },
+    session_id=r"[a-z0-9]{,65}",
+)
 config_templates = mm.templates(__name__)
-methods = ["head", "get", "post", "put", "delete", "options", "patch",
-           "propfind", "report"]
+methods = [
+    "head",
+    "get",
+    "post",
+    "put",
+    "delete",
+    "options",
+    "patch",
+    "propfind",
+    "report",
+]
 applications = {}
 default_session_timeout = 86400
 
 
 def ismethod(obj):
     """"""
-    return (inspect.ismethod(obj) and obj.__name__.isupper() and
-            obj.__name__.lower() in methods)
+    return (
+        inspect.ismethod(obj)
+        and obj.__name__.isupper()
+        and obj.__name__.lower() in methods
+    )
 
 
-def application(name, *wrappers, prefix=r"", mount_prefix=r"",
-                db=True, host=None, static=None, icon=None, sessions=False,
-                serve=False, **path_args):
+def application(
+    name,
+    prefix=r"",
+    mount_prefix=r"",
+    db=True,
+    static=None,  # XXX in favor of explicit mount
+    icon=None,  # XXX in favor of explicit mount
+    mounts=None,
+    wrappers=None,
+    sessions=False,  # XXX in favor of explicitly wrapper
+    host=None,
+    serve=False,
+    **path_args,
+) -> Application:
     if name in applications:
         app = applications[name]
         app.prefix = prefix  # FIXME does this have a side effect?
-        app.add_wrappers(*wrappers)
+        if wrappers:
+            app.add_wrappers(wrappers)
         app.add_path_args(**path_args)
     else:
-        app = Application(name, *wrappers, host=host, **path_args)
+        app = Application(
+            name,
+            db=db,
+            host=host,
+            static=static,
+            icon=icon,
+            sessions=sessions,
+            serve=serve,
+            mounts=mounts,
+            wrappers=wrappers,
+            **path_args,
+        )
         app.reload_config()
         app.prefix = prefix
         app.mount_prefix = mount_prefix
@@ -125,9 +217,13 @@ def setup_servers(root, app, bot):
     with (root / "etc/redis.conf").open("w") as fp:
         fp.write(str(config_templates.redis(root)))
     with (root / "etc/supervisor.conf").open("w") as fp:
-        fp.write(str(config_templates.supervisor(root, root_hash,
-                                                 getpass.getuser(),
-                                                 env, app, bot)))
+        fp.write(
+            str(
+                config_templates.supervisor(
+                    root, root_hash, getpass.getuser(), env, app, bot
+                )
+            )
+        )
     with (root / "etc/nginx.conf").open("w") as fp:
         fp.write(str(config_templates.nginx(root_hash)))
 
@@ -135,9 +231,12 @@ def setup_servers(root, app, bot):
     with (root / "etc/tor_stem_password").open("w") as fp:
         fp.write(str(random.getrandbits(100)))
 
-    session_salt = Crypto.Random.random.randint(10**63, 10**64)
-    cfg = {"root": str(root), "watch": str(env / "src"),
-           "session": {"salt": str(session_salt)}}
+    session_salt = Crypto.Random.random.randint(10 ** 63, 10 ** 64)
+    cfg = {
+        "root": str(root),
+        "watch": str(env / "src"),
+        "session": {"salt": str(session_salt)},
+    }
     with (root / "etc/web.conf").open("w") as fp:
         json.dump(cfg, fp, indent=4, sort_keys=True)
     return root
@@ -149,12 +248,15 @@ def config_servers(root, web_server_config_handler=None):
     root_hash = get_host_hash(root)
     # TODO FIXME XXX figure out what to do here...
     nginx_conf = pathlib.Path("/home/gaea/detritus/nginx/conf")
-    sh.ln("-sf", (root / "etc/nginx.conf").resolve(),
-          nginx_conf / "nginx.conf")
+    sh.ln("-sf", (root / "etc/nginx.conf").resolve(), nginx_conf / "nginx.conf")
     if web_server_config_handler:
         web_server_config_handler(nginx_conf / "conf.d", root_hash)
-    sh.sudo("ln", "-sf", (root / "etc/supervisor.conf").resolve(),
-            "/etc/supervisor/conf.d/{}.conf".format(root_hash))
+    sh.sudo(
+        "ln",
+        "-sf",
+        (root / "etc/supervisor.conf").resolve(),
+        "/etc/supervisor/conf.d/{}.conf".format(root_hash),
+    )
 
 
 def serve(wsgi_app, workers=2):
@@ -168,11 +270,17 @@ def serve(wsgi_app, workers=2):
         # TODO log everything, filter display to relevant
         print(line.rstrip())
 
-    proc = sh.gunicorn(wsgi_app, bind="0.0.0.0:8100",
-                       worker_class="gevent", workers=workers,
-                       _bg=True, _err=process, _out=process)
+    proc = sh.gunicorn(
+        wsgi_app,
+        bind="0.0.0.0:8100",
+        worker_class="gevent",
+        workers=workers,
+        _bg=True,
+        _err=process,
+        _out=process,
+    )
     # if watch:
-    event_handler = EventHandler(proc)
+    event_handler = Watchdog(proc)
     observer = watchdog.observers.Observer()
     observer.schedule(event_handler, ".", recursive=True)
     observer.start()
@@ -184,89 +292,12 @@ def serve(wsgi_app, workers=2):
     proc.signal(signal.SIGQUIT)
 
 
-def serve2(app_name, processes=2, threads=20, max_requests=100, lifespan=60):
-    """Serve callable `app` at given `port`."""
-    # TODO use file sockets specified as relative locations or in environ vars
-    # master_fifo = os.path.expanduser("~/.web/{}-uwsgictl".format(app))
-
-    # __import__(app)
-    # for app_pkg, apps in get_apps().items():
-    #     for app_name, app_instance in apps:
-    #         if app == app_name:
-    #             print(dir(app_pkg))
-    app = applications[app_name]
-
-    def process(line):
-        # TODO log everything, filter display to relevant
-        print(line.rstrip())
-
-    root = pathlib.Path(app.cfg["root"])
-    watch = app.cfg.get("watch")
-    bg = False
-    if watch:
-        bg = True
-    # XXX app_port = 8080
-    proc = sh.uwsgi("-H", os.getenv("VIRTUAL_ENV"), "-w",
-                    "{}.__web__:app".format(app_name),
-                    "--uwsgi-socket", root / "run/web.sock",
-                    "--chmod-socket=666",
-                    # "--http-socket", ":{}".format(app_port),
-                    "--logformat=%(method) %(host)%(uri) %(status)",
-                    "--ignore-sigpipe",
-                    "--max-requests", max_requests,
-                    "--max-worker-lifetime", 60 * lifespan,
-                    # "--master-fifo", master_fifo,
-                    # "--enable-threads",
-                    "-M", "-p", processes, "--async", threads, "--ugreen",
-                    "--stats", root / "run/web-stats.sock",
-                    # XXX "--stats", "127.0.0.1:1717", "--stats-http",
-                    _bg=bg, _err=process)
-    # logging.basicConfig(level=logging.INFO,
-    #                     format='%(asctime)s - %(message)s',
-    #                     datefmt='%Y-%m-%d %H:%M:%S')
-    if watch:
-        event_handler = EventHandler(proc)
-        observer = Observer()
-        observer.schedule(event_handler, str(watch), recursive=True)
-        observer.start()
-        try:
-            proc.wait()
-        except KeyboardInterrupt:
-            observer.stop()
-        observer.join()
-        proc.signal(signal.SIGQUIT)
-
-
-# def serve2(app_name):
-#     """Serve callable `app` at given `port`."""
-#     app = applications[app_name]
-#
-#     def process(line):
-#         # TODO log everything, filter display to relevant
-#         print(line.rstrip())
-#
-#     app_port = 8080
-#     proc = sh.uwsgi("-H", os.getenv("VIRTUAL_ENV"), "-w",
-#                     "{}.__web__:app".format(app_name),
-#                     "--http-socket", ":{}".format(app_port),
-#                     "--logformat=%(method) %(host)%(uri) %(status)",
-#                     "--ignore-sigpipe",
-#                     # "--master-fifo", master_fifo,
-#                     # "--enable-threads",
-#                     # XXX "--stats", "127.0.0.1:1717", "--stats-http",
-#                     _bg=True, _err=process)
-#     def quit():
-#         proc.signal(signal.SIGQUIT)
-#     # proc.wait()
-#     return quit
-
-
-class EventHandler(watchdog.events.FileSystemEventHandler):
+class Watchdog(watchdog.events.FileSystemEventHandler):
     """Restart server when source directory changes."""
 
     def __init__(self, server_proc):
         self.server_proc = server_proc
-        super(EventHandler, self).__init__()
+        super(Watchdog, self).__init__()
 
     def on_modified(self, event):
         if event.src_path.endswith((".py", ".toml")):
@@ -275,29 +306,6 @@ class EventHandler(watchdog.events.FileSystemEventHandler):
                     time.sleep(2)
             self.server_proc.signal(signal.SIGHUP)
 
-    # def on_moved(self, event):
-    #     super(EventHandler, self).on_moved(event)
-    #     # what = 'directory' if event.is_directory else 'file'
-    #     # logging.info("Moved %s: from %s to %s", what, event.src_path,
-    #     #              event.dest_path)
-
-    # def on_created(self, event):
-    #     super(EventHandler, self).on_created(event)
-    #     # what = 'directory' if event.is_directory else 'file'
-    #     # logging.info("Created %s: %s", what, event.src_path)
-
-    # def on_deleted(self, event):
-    #     super(EventHandler, self).on_deleted(event)
-    #     # what = 'directory' if event.is_directory else 'file'
-    #     # logging.info("Deleted %s: %s", what, event.src_path)
-
-    # def on_modified(self, event):
-    #     super(EventHandler, self).on_modified(event)
-    #     # what = 'directory' if event.is_directory else 'file'
-    #     # logging.info("Modified %s: %s", what, event.src_path)
-
-    # on_moved = on_created = on_deleted = ...
-
 
 def get_apps():
     """"""
@@ -312,8 +320,9 @@ def get_apps():
             raw_meta = ep.dist.get_metadata("PKG-INFO")
         except FileNotFoundError:
             raw_meta = ep.dist.get_metadata("METADATA").partition("\n\n")[0]
-        ep.dist.metadata = dict(line.partition(": ")[0::2]
-                                for line in raw_meta.splitlines())
+        ep.dist.metadata = dict(
+            line.partition(": ")[0::2] for line in raw_meta.splitlines()
+        )
         apps[ep.dist].append((ep.name, handler, ep.module_name, ep.attrs))
     return apps
 
@@ -335,10 +344,13 @@ def best_match(handlers, *args, **kwargs):
 
 def get_integrity_factory(template_pkg):
     """Generate integrity hashes on the fly for local assets."""
+
     def handler(fn):
         static_assets_dir = pathlib.Path(template_pkg).parent.parent / "static"
-        return sh.base64(sh.xxd(sh.sha256sum("-b", static_assets_dir / fn),
-                                "-r", "-p")).strip()
+        return sh.base64(
+            sh.xxd(sh.sha256sum("-b", static_assets_dir / fn), "-r", "-p")
+        ).strip()
+
     return handler
 
 
@@ -430,9 +442,7 @@ def secure_form(*args, **kwargs):
 
 class Form(dict):
 
-    """
-
-    """
+    """ """
 
     def __init__(self, *requireds, **defaults):
         _data = tx.request.body._data
@@ -478,18 +488,14 @@ form = Form
 
 class File:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, name, fileobj):
         self.name = name
         self.fileobj = fileobj
 
     def save(self, filepath, **options):
-        """
-
-        """
+        """ """
         filepath = pathlib.Path(filepath)
         # TODO handle required
         required = options.pop("required", False)
@@ -529,9 +535,7 @@ class File:
 
 class Resource:
 
-    """
-
-    """
+    """ """
 
     def __init__(self, **kwargs):
         self.__dict__ = dict(kwargs)
@@ -547,7 +551,10 @@ class Resource:
             try:
                 loader = self.load
             except AttributeError:
-                def loader(): None
+
+                def loader():
+                    None
+
             data = loader()
         self.data = data
 
@@ -590,23 +597,44 @@ class Resource:
 
 def add_job_tables(sqldb):
     """"""
-    sqldb.define(job_signatures="""module TEXT, object TEXT, args BLOB,
-                                   kwargs BLOB, arghash TEXT,
-                                   UNIQUE(module, object, arghash)""",
-                 job_runs="""job_signature_id INTEGER,
-                             job_id TEXT UNIQUE,
-                             created DATETIME NOT NULL
-                               DEFAULT(STRFTIME('%Y-%m-%d %H:%M:%f',
-                                                'NOW')),
-                             started DATETIME, finished DATETIME,
-                             start_time REAL, run_time REAL,
-                             status INTEGER, output TEXT""",
-                 job_schedules="""job_signature_id INTEGER, minute TEXT,
-                                  hour TEXT, day_of_month TEXT,
-                                  month TEXT, day_of_week TEXT,
-                                  UNIQUE(job_signature_id, minute,
-                                         hour, day_of_month, month,
-                                         day_of_week)""")
+    sqldb.define(
+        "job_signatures",
+        module="TEXT",
+        object="TEXT",
+        args="BLOB",
+        kwargs="BLOB",
+        arghash="TEXT",
+        unique=("module", "object", "arghash"),
+    )
+    sqldb.define(
+        "job_runs",
+        job_signature_id="INTEGER",
+        job_id="TEXT UNIQUE",
+        created="DATETIME NOT NULL " "DEFAULT(STRFTIME('%Y-%m-%d %H:%M:%f', 'NOW'))",
+        started="DATETIME",
+        finished="DATETIME",
+        start_time="REAL",
+        run_time="REAL",
+        status="INTEGER",
+        output="TEXT",
+    )
+    sqldb.define(
+        "job_schedules",
+        job_signature_id="INTEGER",
+        minute="TEXT",
+        hour="TEXT",
+        day_of_month="TEXT",
+        month="TEXT",
+        day_of_week="TEXT",
+        unique=(
+            "job_signature_id",
+            "minute",
+            "hour",
+            "day_of_month",
+            "month",
+            "day_of_week",
+        ),
+    )
 
 
 class Application:
@@ -630,17 +658,31 @@ class Application:
 
     """
 
-    def __init__(self, name, *wrappers, db=True, host=None, static=None,
-                 icon=None, sessions=False, serve=False, **path_args):
+    def __init__(
+        self,
+        name,
+        db=True,
+        static=None,
+        icon=None,
+        sessions=False,
+        mounts=None,
+        wrappers=None,
+        host=None,
+        serve=False,
+        **path_args,
+    ):
         self.name = name
         self.wrappers = []
         self.pre_wrappers = []
         self.post_wrappers = []
-        self.add_wrappers(*wrappers)
         self.host = host
         self.path_args = {}
         self.add_path_args(**path_args)
+        if wrappers:
+            self.add_wrappers(*wrappers)
         self.mounts = []
+        if mounts:
+            self.mount(*mounts)
         self.routes = []  # TODO use ordered dict
 
         if db:
@@ -656,8 +698,7 @@ class Application:
 
         class Table:
             def get(innerself):
-                return pprint.pformat([dict(r)
-                                       for r in tx.db.select(innerself.table)])
+                return pprint.pformat([dict(r) for r in tx.db.select(innerself.table)])
 
         self.route(r"admin/db/{table}")(Table)
 
@@ -666,7 +707,7 @@ class Application:
             static_path = pkg_resources.resource_filename(static, "static")
             self.static_path = pathlib.Path(static_path)
         if sessions:  # TODO XXX isn't working in this wrap-order
-            self.db.define(sessions=session_table_sql)
+            self.db.define("sessions", **session_table_sql)
             self.wrap(resume_session, "pre")
         # for method in http.spec.request.methods[:5]:
         #     setattr(self, method, functools.partial(self.get_handler,
@@ -679,14 +720,18 @@ class Application:
         # XXX     except ImportError:
         # XXX         pass
         if icon:
+
             def insert_icon_rels(handler, app):
                 yield
-                if tx.response.status == "200 OK" and \
-                   tx.response.headers.content_type == "text/html":
+                if (
+                    tx.response.status == "200 OK"
+                    and tx.response.headers.content_type == "text/html"
+                ):
                     doc = parse(tx.response.body)
                     head = doc.select("head")[0]
                     head.append("<link rel=icon href=/icon.png>")
                     tx.response.body = doc.html
+
             self.wrap(insert_icon_rels, "post")
 
             if str(icon).endswith("="):  # TODO better test for b64
@@ -703,6 +748,7 @@ class Application:
                             return fp.read()
                     except AttributeError:
                         return payload
+
             self.route(r"icon.png")(Icon)
             self.route(r"favicon.ico")(Icon)
         if serve:
@@ -714,22 +760,23 @@ class Application:
         # XXX monkey.patch_all()
         class Log:
             def write(logline):
-                (_, _, _, _, _, method, path,
-                 _, status, _, duration) = logline.split()
+                _, _, _, _, _, method, path, _, status, _, duration = logline.split()
                 method = method.lstrip('"')
                 duration = round(float(duration) * 1000)
-                message = (f"<div class=httplog>"
-                           f"<span>{self.host}</span>"
-                           f"<span>{method}</span>"
-                           f"<span>{path}</span>"
-                           f"<span>{status}</span>"
-                           f"<span>{duration}<span>ms</span></span>"
-                           f"</div>")
-                print(message)
+                print(
+                    f"<div class=httplog>"
+                    f"<span>{self.host}</span>"
+                    f"<span>{method}</span>"
+                    f"<span>{path}</span>"
+                    f"<span>{status}</span>"
+                    f"<span>{duration}<span>ms</span></span>"
+                    f"</div>"
+                )
+
         server = gevent.pywsgi.WSGIServer((host, port), self, log=Log)
-        server.serve_forever()
-        # TODO self.server = gevent.spawn(server.serve_forever)
-        # TODO self.server.spawn()  # TODO start()?
+        # self.server.serve_forever()
+        self.server = gevent.spawn(server.serve_forever)
+        self.server.spawn()  # TODO start()?
 
     def reload_config(self, path=None):
         self.cfg = {}
@@ -744,8 +791,9 @@ class Application:
         self.wrappers.extend(wrappers)
 
     def add_path_args(self, **path_args):
-        self.path_args.update({k: v.replace(r"\!", nb60_re)
-                               for k, v in path_args.items()})
+        self.path_args.update(
+            {k: v.replace(r"\!", nb60_re) for k, v in path_args.items()}
+        )
 
     def wrap(self, handler, when=None):
         """
@@ -783,6 +831,7 @@ class Application:
         decorate a class to run when request path matches template
 
         """
+
         def register(controller):
             # TODO allow for reuse of parent_app's path_arg definitions
             # XXX try:
@@ -790,13 +839,15 @@ class Application:
             #                          **self.path_args)
             # XXX except AttributeError:
             # XXX     path_args = self.path_args
-            templates = {k: "(?P<{}>{})".format(k, v) for
-                         k, v in self.path_args.items()}
+            templates = {
+                k: "(?P<{}>{})".format(k, v) for k, v in self.path_args.items()
+            }
             try:
                 path = path_template.format(**templates)
             except KeyError as err:
-                raise KeyError("undefined URI fragment"
-                               " type `{}`".format(err.args[0]))
+                raise KeyError(
+                    "undefined URI fragment" " type `{}`".format(err.args[0])
+                )
 
             # TODO metaclass for `__repr__` -- see `app.routes`
             class Route(controller, Resource):
@@ -811,6 +862,7 @@ class Application:
                 pass
             self.routes.append((path.strip("/"), Route))
             return Route
+
         return register
 
     def mount(self, *apps):
@@ -821,8 +873,9 @@ class Application:
         for app in apps:
             app.parent_app = self
             self.add_wrappers(*app.wrappers)  # TODO add pre and post wrappers
-            path = app.mount_prefix.format(**{k: "(?P<{}>{})".format(k, v) for
-                                              k, v in self.path_args.items()})
+            path = app.mount_prefix.format(
+                **{k: "(?P<{}>{})".format(k, v) for k, v in self.path_args.items()}
+            )
             self.mounts.append((path, app))
 
     def __repr__(self):
@@ -850,16 +903,19 @@ class Application:
                         content = fp.read()
                 except FileNotFoundError:
                     raise NotFound("file not found")
-            content_types = {".css": "text/css",
-                             ".js": "application/javascript"}
+            content_types = {".css": "text/css", ".js": "application/javascript"}
             # tx.response.headers.content_type = content_types[asset.suffix]
             header("Content-Type", content_types[asset.suffix])
             start_response("200 OK", tx.response.headers.wsgi)
             return [bytes(content, "utf-8")]
 
         try:
-            tx.host._contextualize(environ, self, tx.request.headers.host.name,
-                                   tx.request.headers.host.port)
+            tx.host._contextualize(
+                environ,
+                self,
+                tx.request.headers.host.name,
+                tx.request.headers.host.port,
+            )
         except AttributeError:
             raise NotFound("no hostname provided")
         tx.user._contextualize(environ)
@@ -914,8 +970,7 @@ class Application:
             elif exc.code in (301, 302, 303, 307, 308):
                 redirect_uri = apply_dns(str(tx.response.body))
                 if redirect_uri.startswith("/"):  # relative HTTP(S) URL
-                    tx.response.headers.location = \
-                        urllib.parse.quote(redirect_uri)
+                    tx.response.headers.location = urllib.parse.quote(redirect_uri)
                 else:  # anything else (moz-extension, etc..)
                     tx.response.headers.location = redirect_uri
             elif exc.code == 405:
@@ -946,9 +1001,9 @@ class Application:
 
         duration = round(time.time() - start, 3)
         duration_color = None
-        if duration < .1:
+        if duration < 0.1:
             pass
-        elif duration < .5:
+        elif duration < 0.5:
             duration_color = "y"
         else:
             duration_color = "r"
@@ -956,7 +1011,7 @@ class Application:
         if duration_color:
             duration = f"/{duration_color}/{duration}/X/"
 
-        status = tx.response.status.partition(' ')[0]
+        status = tx.response.status.partition(" ")[0]
         status_color = None
         if status.startswith("3"):
             status_color = "c"
@@ -1002,9 +1057,7 @@ class Application:
     #     return handler()
 
     def get_controller(self, path):
-        """
-
-        """
+        """ """
         # TODO softcode `static/` reference
         if path.endswith("/") and not path.startswith("static/"):
             raise PermanentRedirect("/" + path.rstrip("/"))
@@ -1012,7 +1065,7 @@ class Application:
         for mount, app in self.mounts:
             m = re.match(mount, path)
             if m:
-                controller = app.get_controller(path[m.span()[1]:].lstrip("/"))
+                controller = app.get_controller(path[m.span()[1] :].lstrip("/"))
                 for k, v in m.groupdict().items():
                     setattr(controller, k, v)
                 return controller
@@ -1033,15 +1086,17 @@ class Application:
                 if isinstance(resource, str):
                     mod = __import__(resource.__module__)
                     resource = getattr(mod, resource)
-                match = re.match(r"^{}$".format(pattern),
-                                 urllib.parse.unquote(path))
+                match = re.match(r"^{}$".format(pattern), urllib.parse.unquote(path))
                 if match:
                     return resource, match
             return ResourceNotFound, None
 
         resource, match = get_resource()  # TODO for-else or try-block instead?
-        unquoted = {k: urllib.parse.unquote(v) for k, v
-                    in match.groupdict().items() if v} if match else {}
+        unquoted = (
+            {k: urllib.parse.unquote(v) for k, v in match.groupdict().items() if v}
+            if match
+            else {}
+        )
         return resource(**unquoted)
 
     def get_handler(self, controller, method="get"):
@@ -1064,6 +1119,7 @@ def sessions(**defaults):  # TODO XXX
     returns an application hook for session handling using given redis `db`
 
     """
+
     def hook(handler, app):
         try:
             identifier = tx.request.headers["cookie"].morsels["session"]
@@ -1071,15 +1127,17 @@ def sessions(**defaults):  # TODO XXX
             identifier = 0
         if ("sessions", identifier) not in kvdb:
             while True:
-                secret = "{}{}{}{}".format(random.getrandbits(128),
-                                           app.cfg["session"]["salt"],
-                                           time.time(), tx.user.ip)
+                secret = "{}{}{}{}".format(
+                    random.getrandbits(128),
+                    app.cfg["session"]["salt"],
+                    time.time(),
+                    tx.user.ip,
+                )
                 secret_hash = hashlib.sha256(secret.encode("utf-8"))
                 identifier = secret_hash.hexdigest()
                 if kvdb["sessions", identifier].setnx("anonymous"):
                     break
-        session_timeout = app.cfg["session"].get("timeout",
-                                                 default_session_timeout)
+        session_timeout = app.cfg["session"].get("timeout", default_session_timeout)
         kvdb["sessions", identifier].expire(session_timeout)
         # FIXME user.session = kvdb.hgetall(kvdb(user.identifier, "data"))
         data = kvdb["sessions", identifier, "data"]
@@ -1091,8 +1149,7 @@ def sessions(**defaults):  # TODO XXX
         tx.user.session = data
         tx.user.identifier = identifier
         yield
-        kvdb["sessions", identifier, "data"] = \
-            JSONEncoder().encode(tx.user.session)
+        kvdb["sessions", identifier, "data"] = JSONEncoder().encode(tx.user.session)
         kvdb["sessions", identifier, "data"].expire(session_timeout)
         # FIXME kvdb.delete("data")
         # FIXME if user.session:
@@ -1100,13 +1157,15 @@ def sessions(**defaults):  # TODO XXX
         # XXX print(identifier, data, tx.user.identifier, tx.user.session)
         tx.response.headers["set-cookie"] = (("session", tx.user.identifier),)
         # ("Domain", tx.host.name))
+
     return hook
 
 
-session_table_sql = """timestamp DATETIME NOT NULL
-                           DEFAULT CURRENT_TIMESTAMP,
-                       identifier TEXT NOT NULL UNIQUE,
-                       data TEXT NOT NULL"""
+session_table_sql = dict(
+    timestamp="DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP",
+    identifier="TEXT NOT NULL UNIQUE",
+    data="TEXT NOT NULL",
+)
 
 
 def resume_session(handler, app):
@@ -1119,8 +1178,9 @@ def resume_session(handler, app):
         identifier = None
     else:
         try:
-            session = tx.db.select("sessions", where="identifier = ?",
-                                   vals=[identifier])[0]
+            session = tx.db.select(
+                "sessions", where="identifier = ?", vals=[identifier]
+            )[0]
         except IndexError:
             identifier = None
         else:
@@ -1135,18 +1195,27 @@ def resume_session(handler, app):
             salt = "abcdefg"  # FIXME
             secret = f"{random.getrandbits(64)}{salt}{time.time()}{tx.user.ip}"
             identifier = hashlib.sha256(secret.encode("utf-8")).hexdigest()
-            tx.user.session.update(ip=tx.user.ip,
-                                   ua=str(tx.request.headers["user-agent"]))
+            tx.user.session.update(
+                ip=tx.user.ip, ua=str(tx.request.headers["user-agent"])
+            )
             # TODO FIXME add Secure for HTTPS sites (eg. canopy)!
-            tx.response.headers["set-cookie"] = (("session", identifier),
-                                                 ("path", "/"),
-                                                 # "Secure",
-                                                 "HttpOnly")
-        tx.db.replace("sessions", identifier=identifier,
-                      data=JSONEncoder().encode(tx.user.session))
+            tx.response.headers["set-cookie"] = (
+                ("session", identifier),
+                ("path", "/"),
+                # "Secure",
+                "HttpOnly",
+            )
+        tx.db.replace(
+            "sessions",
+            identifier=identifier,
+            data=JSONEncoder().encode(tx.user.session),
+        )
     else:
-        tx.response.headers["set-cookie"] = (("session", identifier),
-                                             ("path", "/"), ("max-age", 0))
+        tx.response.headers["set-cookie"] = (
+            ("session", identifier),
+            ("path", "/"),
+            ("max-age", 0),
+        )
 
 
 # TODO roles eg. owner, guest (personal context) && admin, user (service)
@@ -1156,12 +1225,13 @@ def require_auth(*roles):
             if tx.user.session["role"] not in roles:  # TODO role -> roles
                 raise Unauthorized("no auth to access this resource")
             return func(*args, **kwargs)
+
         return handler
+
     return decorate
 
 
 class Session(dict):
-
     def __getattr__(self, name):
         try:
             return self[name]
@@ -1204,13 +1274,20 @@ def get_job_signature(callable, *args, **kwargs):
     _kwargs = json.dumps(kwargs)
     arghash = hashlib.sha256((_args + _kwargs).encode("utf-8")).hexdigest()
     try:
-        job_signature_id = tx.db.insert("job_signatures", module=_module,
-                                        object=_object, args=_args,
-                                        kwargs=_kwargs, arghash=arghash)
+        job_signature_id = tx.db.insert(
+            "job_signatures",
+            module=_module,
+            object=_object,
+            args=_args,
+            kwargs=_kwargs,
+            arghash=arghash,
+        )
     except tx.db.IntegrityError:
-        job_signature_id = tx.db.select("job_signatures", what="rowid, *",
-                                        where="""module = ? AND object = ? AND
+        job_signature_id = tx.db.select(
+            "job_signatures",
+            what="rowid, *",
+            where="""module = ? AND object = ? AND
                                                  arghash = ?""",
-                                        vals=[_module, _object,
-                                              arghash])[0]["rowid"]
+            vals=[_module, _object, arghash],
+        )[0]["rowid"]
     return job_signature_id
