@@ -12,9 +12,7 @@ __all__ = ["get_header", "Headers"]
 
 
 def get_header(header, value=None):
-    """
-
-    """
+    """ """
     header = header.lower().replace("_", "").replace("-", "")
     for header_type in (entity, general, request, response):
         for search_name in header_type.__all__:
@@ -26,8 +24,8 @@ def get_header(header, value=None):
 def _title_case(header):
     """
 
-        >>> _title_case("accept_Encoding")
-        'Accept-Encoding'
+    >>> _title_case("accept_Encoding")
+    'Accept-Encoding'
 
     """
     # TODO re.split on -, _, whitespace, or camelcase
@@ -95,8 +93,9 @@ class Headers(dict):
         for k, v in self.__dict__.items():
             # if v.__class__.__name__ in ["SetCookie"]:
             #     headers[_title_case(k)] = v.header
-            if issubclass(v.__class__, (response.Response, entity.Entity,
-                                        general.General)):
+            if issubclass(
+                v.__class__, (response.Response, entity.Entity, general.General)
+            ):
                 headers[_title_case(k)] = str(v)
         return headers
 
