@@ -15,12 +15,24 @@ from .. import webmention
 from .util import discover_post_type
 
 
-server = web.application("MicropubServer", mount_prefix="pub", db=False,
-                         channel=r".+", entry=r".+", nickname=r"[A-Za-z0-9-]+",
-                         filename=rf"{web.nb60_re}{{4}}.\w{{1,10}}")
-content = web.application("MicropubContent", db=False,
-                          year=r"\d{4}", month=r"\d{2}", day=r"\d{2}",
-                          seconds=web.nb60_re + r"{,4}", slug=r"[\w_-]+")
+server = web.application(
+    "MicropubServer",
+    mount_prefix="pub",
+    db=False,
+    channel=r".+",
+    entry=r".+",
+    nickname=r"[A-Za-z0-9-]+",
+    filename=rf"{web.nb60_re}{{4}}.\w{{1,10}}",
+)
+content = web.application(
+    "MicropubContent",
+    db=False,
+    year=r"\d{4}",
+    month=r"\d{2}",
+    day=r"\d{2}",
+    seconds=web.nb60_re + r"{,4}",
+    slug=r"[\w_-]+",
+)
 templates = web.templates(__name__)
 
 # TODO supported_types = {"RSVP": ["in-reply-to", "rsvp"]}
@@ -31,28 +43,28 @@ def send(properties, endpoint=None, h="entry", token=None):
     # TODO FIXME what's in the session?
     if endpoint is None:
         endpoint = tx.user.session["micropub_endpoint"]
-    response = web.post(endpoint, headers={"Authorization": f"Bearer {token}"},
-                        json={"type": [f"h-{h}"], "properties": properties})
+    response = web.post(
+        endpoint,
+        headers={"Authorization": f"Bearer {token}"},
+        json={"type": [f"h-{h}"], "properties": properties},
+    )
     return response.location, response.links
 
 
 def define_table():
     """Define the `resources`, `media` and `syndication` tables."""
-    tx.db.define(resources="""permalink TEXT UNIQUE, version TEXT UNIQUE,
-                              resource JSON""",
-                 # TODO updates="""""",
-                 media="""mid TEXT, sha256 TEXT UNIQUE, size INTEGER""",
-                 syndication="""destination JSON NOT NULL""")
+    tx.db.define(
+        "resources", permalink="TEXT UNIQUE", version="TEXT UNIQUE", resource="JSON"
+    )
+    # TODO tx.db.define("updates")
+    tx.db.define("media", mid="TEXT", sha256="TEXT UNIQUE", size="INTEGER")
+    tx.db.define("syndication", destination="JSON NOT NULL")
 
 
 def wrap_server(handler, app):
     """Ensure server links are in head of root document."""
     define_table()
     tx.pub = LocalClient()
-    try:
-        tx.host.owner = tx.pub.get_card("me")
-    except IndexError:
-        tx.host.owner = {}
     yield
     if tx.request.uri.path == "" and tx.response.body:
         doc = web.parse(tx.response.body)
@@ -162,32 +174,56 @@ class LocalClient:
             flat_values = []
             for v in resource[k]:
                 if isinstance(v, dict):
-                    v = dict(**v["properties"],
-                             type=v["type"][0].removeprefix("h-"))
+                    v = dict(**v["properties"], type=[v["type"][0].removeprefix("h-")])
                 flat_values.append(v)
             resource[k] = flat_values
-        if "published" in resource:
-            resource["published"][0]["datetime"] = \
-                pendulum.from_format(resource["published"][0]["datetime"],
-                                     "YYYY-MM-DDTHH:mm:ssZ")
-            published = resource["published"]
-        else:
-            published = [{"datetime": web.utcnow(),
-                          "timezone": "America/Los_Angeles"}]
+
+        # TODO --##--
+        resource["published"] = [
+            {"datetime": web.utcnow(), "timezone": "America/Los_Angeles"}
+        ]
+        for date_prop in ("published", "updated"):
+            try:
+                resource[date_prop][0]["datetime"] = pendulum.from_format(
+                    resource[date_prop][0]["datetime"], "YYYY-MM-DDTHH:mm:ssZ"
+                )
+                # TODO assert `timezone` exists
+            except KeyError:
+                pass
+        # if "published" in resource:
+        #     resource["published"][0]["datetime"] = \
+        #         pendulum.from_format(resource["published"][0]["datetime"],
+        #                              "YYYY-MM-DDTHH:mm:ssZ")
+        #     published = resource["published"]
+        # else:
+        #     published = [{"datetime": web.utcnow(),
+        #                   "timezone": "America/Los_Angeles"}]
+        # TODO --##--
+
         resource["visibility"] = resource.get("visibility", ["public"])
-        resource["channel"] = resource.get("channel", ["default"])
+        # XXX resource["channel"] = resource.get("channel", [])
         mentions = []
         urls = resource.pop("url", [])
         if resource_type == "card":
             slug = resource.get("nickname", resource.get("name"))[0]
             urls.insert(0, f"/pub/cards/{web.textslug(slug)}")
-            resource.update(published=published)
         elif resource_type == "feed":
-            slug = resource["name"][0]
-            if not urls:
-                urls.append(f"/{web.textslug(slug)}")
-            resource.pop("channel")
+            name_slug = web.textslug(resource["name"][0])
+            try:
+                slug = resource["slug"][0]
+            except KeyError:
+                slug = name_slug
+            resource.update(uid=[slug if slug else name_slug])
+            resource.pop("channel", None)
+            # XXX urls.insert(0, f"/{slug}")
         elif resource_type == "entry":
+            #                                         REQUEST URL
+            # 1) given: url=/xyz                        => look for exact match
+            #     then: url=[/xyz, /2021/3/5...]
+            # 2) given: channel=abc, slug=foo           => construct
+            #     then: url=[/2021/3/5...]
+            # 3) given: no slug                         => only via permalink
+            #     then: url=[/2021/3/5...]
             post_type = discover_post_type(resource)
             slug = None
             if post_type == "article":
@@ -210,21 +246,21 @@ class LocalClient:
             #     textslug = follows[0]["name"]
             #     mentions.append(follows[0]["url"])
             #     tx.sub.follow(follows[0]["url"])
-            author_id = tx.db.select("resources",
-                                     where="""json_extract(resources.resource,
+            author_id = tx.db.select(
+                "resources",
+                where="""json_extract(resources.resource,
                                                   '$.uid[0]') == ?""",
-                                     vals=[tx.origin])[0]["version"]
+                vals=[tx.origin],
+            )[0]["version"]
             resource.update(author=[author_id])
         # elif resource_type == "event":
         #     slug = resource.get("nickname", resource.get("name"))[0]
         #     urls.insert(0, f"/pub/cards/{web.textslug(slug)}")
         #     # if resource["uid"] == str(web.uri(tx.host.name)):
         #     #     pass
-        resource.update(published=published, url=urls)
-        resource["type"] = [resource_type]
-        # XXX from pprint import pprint
-        # XXX pprint(resource_kwargs)
-        permalink_base = f"/{web.timeslug(published[0]['datetime'])}"
+        resource.update(url=urls, type=[resource_type])
+        published = resource["published"][0]["datetime"]
+        permalink_base = f"/{web.timeslug(published)}"
 
         def generate_trailer():
             letterspace = "abcdefghijkmnopqrstuvwxyz23456789"
@@ -238,11 +274,16 @@ class LocalClient:
             permalink = f"{permalink_base}/{generate_trailer()}"
             resource["url"].append(permalink)
             try:
-                tx.db.insert("resources", permalink=permalink,
-                             version=web.nbrandom(10), resource=resource)
+                tx.db.insert(
+                    "resources",
+                    permalink=permalink,
+                    version=web.nbrandom(10),
+                    resource=resource,
+                )
             except tx.db.IntegrityError:
                 continue
             break
+
         web.publish("/recent", ".feed[-0:-0]", resource)
         for mention in mentions:
             web.enqueue(webmention.send, f"{tx.origin}{permalink}", mention)
@@ -256,18 +297,22 @@ class LocalClient:
         if not url.startswith(("http://", "https://")):
             url = f"/{url.strip('/')}"
         try:
-            resource = tx.db.select("resources",
-                                    where="""json_extract(
+            resource = tx.db.select(
+                "resources",
+                where="""json_extract(
                                                  resources.resource,
                                                  '$.url[0]') == ?""",
-                                    vals=[url])[0]
+                vals=[url],
+            )[0]
         except IndexError:
             try:
-                resource = tx.db.select("resources",
-                                        where="""json_extract(
+                resource = tx.db.select(
+                    "resources",
+                    where="""json_extract(
                                                      resources.resource,
                                                      '$.alias[0]') == ?""",
-                                        vals=[url])[0]
+                    vals=[url],
+                )[0]
             except IndexError:
                 web.header("Content-Type", "text/html")  # TODO FIXME XXX
                 raise web.NotFound(templates.post_not_found(url))
@@ -280,16 +325,16 @@ class LocalClient:
         """Update a resource."""
         now = web.utcnow()
         path = f"/{url.strip('/')}"
-        resource = tx.db.select("resources", where="path = ?",
-                                vals=[path])[0]["resource"]
+        resource = tx.db.select("resources", where="path = ?", vals=[path])[0][
+            "resource"
+        ]
         for prop, vals in add.items():
             try:
                 resource[prop].extend(vals)
             except KeyError:
                 resource[prop] = vals
         resource["updated"] = now
-        tx.db.update("resources", resource=resource,
-                     where="path = ?", vals=[path])
+        tx.db.update("resources", resource=resource, where="path = ?", vals=[path])
         # TODO web.publish(url, f".{prop}[-0:-0]", vals)
 
     def delete(self, url):
@@ -306,17 +351,19 @@ class LocalClient:
 
     def get_version(self, version):
         """Return a snapshot of resource at given version."""
-        return tx.db.select("resources", where="version = ?",
-                            vals=[version])[0]
+        return tx.db.select("resources", where="version = ?", vals=[version])[0]
 
     def get_entry(self, path):
         """"""
 
     def get_card(self, nickname):
         """Return the card with given nickname."""
-        resource = tx.db.select("resources", vals=[nickname],
-                                where="""json_extract(resources.resource,
-                                             '$.nickname[0]') == ?""")[0]
+        resource = tx.db.select(
+            "resources",
+            vals=[nickname],
+            where="""json_extract(resources.resource,
+                                             '$.nickname[0]') == ?""",
+        )[0]
         return resource["resource"]
 
     def get_event(self, path):
@@ -324,38 +371,49 @@ class LocalClient:
 
     def get_entries(self, limit=20, modified="DESC"):
         """Return a list of entries."""
-        return tx.db.select("resources",
-                            order=f"""json_extract(resources.resource,
+        return tx.db.select(
+            "resources",
+            order=f"""json_extract(resources.resource,
                                           '$.published[0]') {modified}""",
-                            where="""json_extract(resources.resource,
+            where="""json_extract(resources.resource,
                                          '$.type[0]') == 'entry'""",
-                            limit=limit)
+            limit=limit,
+        )
 
     def get_cards(self, limit=20):
         """Return a list of alphabetical cards."""
-        return tx.db.select("resources",  # order="modified DESC",
-                            where="""json_extract(resources.resource,
-                                         '$.type[0]') == 'card'""")
+        return tx.db.select(
+            "resources",  # order="modified DESC",
+            where="""json_extract(resources.resource,
+                                         '$.type[0]') == 'card'""",
+        )
 
     def get_rooms(self, limit=20):
         """Return a list of alphabetical rooms."""
-        return tx.db.select("resources",  # order="modified DESC",
-                            where="""json_extract(resources.resource,
-                                         '$.type[0]') == 'room'""")
+        return tx.db.select(
+            "resources",  # order="modified DESC",
+            where="""json_extract(resources.resource,
+                                         '$.type[0]') == 'room'""",
+        )
 
     def get_channels(self):
         """Return a list of alphabetical channels."""
-        return tx.db.select("resources",  # order="modified DESC",
-                            where="""json_extract(resources.resource,
-                                         '$.type[0]') == 'feed'""")
+        return tx.db.select(
+            "resources",  # order="modified DESC",
+            where="""json_extract(resources.resource,
+                                         '$.type[0]') == 'feed'""",
+        )
 
     def get_posts_by_channel(self, uid):
         """Return the card with given nickname."""
-        return tx.db.select("resources", vals=[uid],
-                            where="""json_extract(resources.resource,
+        return tx.db.select(
+            "resources",
+            vals=[uid],
+            where="""json_extract(resources.resource,
                                          '$.channel[0]') == ?""",
-                            order="""json_extract(resources.resource,
-                                         '$.published[0]') DESC""")
+            order="""json_extract(resources.resource,
+                                         '$.published[0]') DESC""",
+        )
 
     # def get_channels(self):
     #     """Return a list of channels."""
@@ -365,12 +423,14 @@ class LocalClient:
     #                          what="DISTINCT value", where="type = 'text'")]
 
     def get_year(self, year):
-        return tx.db.select("resources",
-                            order="""json_extract(resources.resource,
+        return tx.db.select(
+            "resources",
+            order="""json_extract(resources.resource,
                                          '$.published[0].datetime') ASC""",
-                            where=f"""json_extract(resources.resource,
+            where=f"""json_extract(resources.resource,
                                           '$.published[0].datetime')
-                                          LIKE '{year}%'""")
+                                          LIKE '{year}%'""",
+        )
 
     def get_media(self):
         """Return a list of media filepaths."""
@@ -401,34 +461,45 @@ class MicropubEndpoint:
             reviews = []  # local_client.get_reviews()
             rooms = local_client.get_rooms()
             media = local_client.get_media()
-            return templates.activity(channels, entries, cards, events,
-                                      reviews, rooms, media)
+            return templates.activity(
+                channels, entries, cards, events, reviews, rooms, media
+            )
         syndication_endpoints = []
 
         def generate_channels():
-            return [{"name": r["name"][0],
-                     "uid": r["uid"][0]} for r in local_client.get_channels()]
+            return [
+                {"name": r["name"][0], "uid": r["uid"][0]}
+                for r in local_client.get_channels()
+            ]
 
         if form.q == "config":
-            response = {"q": ["category", "contact", "source", "syndicate-to"],
-                        "media-endpoint": f"https://{tx.host.name}/pub/media",
-                        "syndicate-to": syndication_endpoints,
-                        "visibility": ["public", "unlisted", "private"]}
+            response = {
+                "q": ["category", "contact", "source", "syndicate-to"],
+                "media-endpoint": f"https://{tx.host.name}/pub/media",
+                "syndicate-to": syndication_endpoints,
+                "visibility": ["public", "unlisted", "private"],
+            }
             # TODO "channels": generate_channels()}
         elif form.q == "channel":
             response = {"channels": generate_channels()}
         elif form.q == "source":
             response = {}
             if "search" in form:
-                response = {"items": [{"url": [r["resource"]["url"]]} for r in
-                                      local_client.search(form.search)]}
+                response = {
+                    "items": [
+                        {"url": [r["resource"]["url"]]}
+                        for r in local_client.search(form.search)
+                    ]
+                }
             elif "url" in form:
                 response = dict(local_client.read(form.url))
             else:
                 pass  # TODO list all posts
         else:
-            raise web.BadRequest("""unsupported query.
-                                    check `q=config` for support.""")
+            raise web.BadRequest(
+                """unsupported query.
+                                    check `q=config` for support."""
+            )
         web.header("Content-Type", "application/json")
         return response
 
@@ -438,9 +509,11 @@ class MicropubEndpoint:
         except web.BadRequest:
             resource = tx.request.body._data
         else:
-            h = form.pop('h')
-            properties = {k.rstrip("[]"): (v if isinstance(v, list) else [v])
-                          for k, v in form.items()}
+            h = form.pop("h")
+            properties = {
+                k.rstrip("[]"): (v if isinstance(v, list) else [v])
+                for k, v in form.items()
+            }
             resource = {"type": [f"h-{h}"], "properties": properties}
         client = LocalClient()
         action = resource.pop("action", None)
@@ -448,8 +521,13 @@ class MicropubEndpoint:
             url = resource.pop("url")
             client.update(url, **resource)
             return
-        permalink = client.create(resource["type"][0].partition("-")[2],
-                                  **resource["properties"])
+        elif action == "delete":
+            pass
+        elif action == "undelete":
+            pass
+        permalink = client.create(
+            resource["type"][0].partition("-")[2], **resource["properties"]
+        )
         # web.header("Link", '</blat>; rel="shortlink"', add=True)
         # web.header("Link", '<https://twitter.com/angelogladding/status/'
         #                    '30493490238590234>; rel="syndication"', add=True)
@@ -477,8 +555,7 @@ class Entries:
     """All entries on file."""
 
     def get(self):
-        return templates.entries(LocalClient().get_entries(),
-                                 templates.render_dict)
+        return templates.entries(LocalClient().get_entries(), templates.render_dict)
 
 
 @server.route(r"entries/{entry}")
@@ -487,11 +564,13 @@ class Entry:
 
     def get(self):
         try:
-            resource = tx.db.select("cache", where="url = ?",
-                                    vals=[f"https://{self.resource}"])[0]
+            resource = tx.db.select(
+                "cache", where="url = ?", vals=[f"https://{self.resource}"]
+            )[0]
         except IndexError:
-            resource = tx.db.select("cache", where="url = ?",
-                                    vals=[f"http://{self.resource}"])[0]
+            resource = tx.db.select(
+                "cache", where="url = ?", vals=[f"http://{self.resource}"]
+            )[0]
         return templates.cache_resource(resource)
 
 
@@ -510,9 +589,12 @@ class Cards:
     def options(self):
         """Signal capabilities to CardDAV client."""
         web.header("DAV", "1, 2, 3, access-control, addressbook")
-        web.header("Allow", "OPTIONS, GET, HEAD, POST, PUT, DELETE, TRACE, "
-                            "COPY, MOVE, MKCOL, PROPFIND, PROPPATCH, LOCK, "
-                            "UNLOCK, REPORT, ACL")
+        web.header(
+            "Allow",
+            "OPTIONS, GET, HEAD, POST, PUT, DELETE, TRACE, "
+            "COPY, MOVE, MKCOL, PROPFIND, PROPPATCH, LOCK, "
+            "UNLOCK, REPORT, ACL",
+        )
         tx.response.naked = True
         return ""
 
@@ -533,8 +615,9 @@ class Cards:
         etags = {"": tx.kv["carddav-lasttouch"]}
         if depth == 1:
             for identity in get_resources("identities"):
-                etags[identity["-uuid"]] = \
-                    identity.get("updated", identity["published"]).timestamp()
+                etags[identity["-uuid"]] = identity.get(
+                    "updated", identity["published"]
+                ).timestamp()
 
         props = list(tx.request.body.iterchildren())[0]
         namespaces = set()
@@ -546,7 +629,8 @@ class Cards:
             for prop in props.iterchildren():
                 # supported
                 if prop.tag == "{DAV:}current-user-privilege-set":
-                    ok.append("""<current-user-privilege-set>
+                    ok.append(
+                        """<current-user-privilege-set>
                                      <privilege>
                                          <all />
                                          <read />
@@ -554,7 +638,8 @@ class Cards:
                                          <write-properties />
                                          <write-content />
                                      </privilege>
-                                 </current-user-privilege-set>""")
+                                 </current-user-privilege-set>"""
+                    )
                 if prop.tag == "{DAV:}displayname":
                     ok.append("<displayname>carddav</displayname>")
                 if prop.tag == "{DAV:}getetag":
@@ -562,28 +647,37 @@ class Cards:
                 if prop.tag == "{DAV:}owner":
                     ok.append("<owner>/</owner>")
                 if prop.tag == "{DAV:}principal-URL":
-                    ok.append("""<principal-URL>
+                    ok.append(
+                        """<principal-URL>
                                      <href>/identities</href>
-                                 </principal-URL>""")
+                                 </principal-URL>"""
+                    )
                 if prop.tag == "{DAV:}principal-collection-set":
-                    ok.append("""<principal-collection-set>
+                    ok.append(
+                        """<principal-collection-set>
                                      <href>/identities</href>
-                                 </principal-collection-set>""")
+                                 </principal-collection-set>"""
+                    )
                 if prop.tag == "{DAV:}current-user-principal":
-                    ok.append("""<current-user-principal>
+                    ok.append(
+                        """<current-user-principal>
                                      <href>/identities</href>
-                                 </current-user-principal>""")
+                                 </current-user-principal>"""
+                    )
                 if prop.tag == "{DAV:}resourcetype":
                     namespaces.add("CR")
                     if uuid:
                         ok.append("<resourcetype />")
                     else:
-                        ok.append("""<resourcetype>
+                        ok.append(
+                            """<resourcetype>
                                          <CR:addressbook />
                                          <collection />
-                                     </resourcetype>""")
+                                     </resourcetype>"""
+                        )
                 if prop.tag == "{DAV:}supported-report-set":
-                    ok.append("""<supported-report-set>
+                    ok.append(
+                        """<supported-report-set>
                                      <supported-report>
                                          <report>principal-property-search</report>
                                      </supported-report>
@@ -596,27 +690,33 @@ class Cards:
                                      <supported-report>
                                          <report>principal-search-property-set</report>
                                      </supported-report>
-                                 </supported-report-set>""")
-                if (prop.tag == "{urn:ietf:params:xml:ns:carddav}"
-                                "addressbook-home-set"):
+                                 </supported-report-set>"""
+                    )
+                if (
+                    prop.tag == "{urn:ietf:params:xml:ns:carddav}"
+                    "addressbook-home-set"
+                ):
                     namespaces.add("CR")
-                    ok.append("""<CR:addressbook-home-set>
+                    ok.append(
+                        """<CR:addressbook-home-set>
                                      <href>/identities</href>
-                                 </CR:addressbook-home-set>""")
-                if (prop.tag == "{http://calendarserver.org/ns/}"
-                                "getctag"):
+                                 </CR:addressbook-home-set>"""
+                    )
+                if prop.tag == "{http://calendarserver.org/ns/}" "getctag":
                     namespaces.add("CS")
                     ok.append(f'<CS:getctag>"{etag}"</CS:getctag>')
 
                 # conditionally supported
-                if (prop.tag == "{http://calendarserver.org/ns/}me-card"):
+                if prop.tag == "{http://calendarserver.org/ns/}me-card":
                     namespaces.add("CS")
                     if uuid:
                         notfound.append("<CS:me-card />")
                     else:
-                        ok.append(f"""<CS:me-card>
+                        ok.append(
+                            f"""<CS:me-card>
                                       <href>/identities/{tx.owner["-uuid"]}.vcf</href>
-                                      </CS:me-card>""")
+                                      </CS:me-card>"""
+                        )
 
                 # not supported
                 if prop.tag == "{DAV:}add-member":
@@ -629,32 +729,25 @@ class Cards:
                     notfound.append("<resource-id />")
                 if prop.tag == "{DAV:}sync-token":
                     notfound.append("<sync-token />")
-                if (prop.tag == "{urn:ietf:params:xml:ns:carddav}"
-                                "directory-gateway"):
+                if prop.tag == "{urn:ietf:params:xml:ns:carddav}" "directory-gateway":
                     namespaces.add("CR")
                     notfound.append("<CR:directory-gateway />")
-                if (prop.tag == "{urn:ietf:params:xml:ns:carddav}"
-                                "max-image-size"):
+                if prop.tag == "{urn:ietf:params:xml:ns:carddav}" "max-image-size":
                     namespaces.add("CR")
                     notfound.append("<CR:max-image-size />")
-                if (prop.tag == "{urn:ietf:params:xml:ns:carddav}"
-                                "max-resource-size"):
+                if prop.tag == "{urn:ietf:params:xml:ns:carddav}" "max-resource-size":
                     namespaces.add("CR")
                     notfound.append("<CR:max-resource-size />")
-                if (prop.tag == "{http://calendarserver.org/ns/}"
-                                "email-address-set"):
+                if prop.tag == "{http://calendarserver.org/ns/}" "email-address-set":
                     namespaces.add("CS")
                     notfound.append("<CS:email-address-set />")
-                if (prop.tag == "{http://calendarserver.org/ns/}"
-                                "push-transports"):
+                if prop.tag == "{http://calendarserver.org/ns/}" "push-transports":
                     namespaces.add("CS")
                     notfound.append("<CS:push-transports />")
-                if (prop.tag == "{http://calendarserver.org/ns/}"
-                                "pushkey"):
+                if prop.tag == "{http://calendarserver.org/ns/}" "pushkey":
                     namespaces.add("CS")
                     notfound.append("<CS:pushkey />")
-                if (prop.tag == "{http://me.com/_namespace/}"
-                                "bulk-requests"):
+                if prop.tag == "{http://me.com/_namespace/}" "bulk-requests":
                     namespaces.add("ME")
                     notfound.append("<ME:bulk-requests />")
             href = "/identities"
@@ -668,15 +761,18 @@ class Cards:
         """Return a full listing for each requested identity."""
         etags = {}
         for identity in get_resources("identities"):
-            etags[identity["-uuid"]] = \
-                identity.get("updated", identity["published"]).timestamp()
+            etags[identity["-uuid"]] = identity.get(
+                "updated", identity["published"]
+            ).timestamp()
         children = list(tx.request.body.iterchildren())
         # XXX props = children[0]  # TODO soft-code prop responses
         responses = []
         for href in children[1:]:
             uuid = href.text.rpartition("/")[2].partition(".")[0]
-            ok = [f'<getetag>"{etags[uuid]}"</getetag>',
-                  f"<CR:address-data>{generate_vcard(uuid)}</CR:address-data>"]
+            ok = [
+                f'<getetag>"{etags[uuid]}"</getetag>',
+                f"<CR:address-data>{generate_vcard(uuid)}</CR:address-data>",
+            ]
             notfound = []
             responses.append((href.text, ok, notfound))
         tx.response.naked = True
@@ -701,7 +797,7 @@ class Card:
 class VCard:
     """
     A single card on file, represented as a vCard.
-    
+
     `PUT` and `DELETE` methods provide CardDAV support.
 
     """
@@ -736,8 +832,7 @@ class VCard:
             pass
         else:
             identity = identities.get_identity_by_uuid(self.card_id)
-            current_etag = \
-                identity.get("updated", identity["published"]).timestamp()
+            current_etag = identity.get("updated", identity["published"]).timestamp()
             print("current etag", current_etag)
             if request_etag != current_etag:
                 raise web.Conflict("previous edit already exists")
@@ -757,6 +852,7 @@ class VCard:
                 extended[key] = ";".join(item)
             else:
                 extended[key] = [item]
+
         explode("prefix")
         explode("given")
         explode("additional")
@@ -807,8 +903,7 @@ class VCard:
             print("NEW identity!")
             print(basic)
             print(extended)
-            quick_draft("identity", basic,
-                        publish="Identity imported from iPhone.")
+            quick_draft("identity", basic, publish="Identity imported from iPhone.")
             # XXX details = create_identity(access="private", uid=self.card_id,
             # XXX                          **basic)
             # XXX details = update_identity(identifier=details["identifier"],
@@ -827,8 +922,7 @@ class VCard:
         etag = identity.get("updated", identity["published"]).timestamp()
         web.header("ETag", f'"{etag}"')
         tx.response.naked = True
-        raise web.Created("created identity",
-                          f"/identities/{self.card_id}.vcf")
+        raise web.Created("created identity", f"/identities/{self.card_id}.vcf")
 
     def delete(self):
         """
@@ -870,28 +964,32 @@ class Syndication:
             # TODO pw = destinations.twitter_password
             # TODO sign in
             user_photo = ""  # TODO doc.qS(f"a[href=/{un}/photo] img").src
-            destination = {"uid": f"//twitter.com/{un}",
-                           "name": f"{un} on Twitter",
-                           "service": {"name": "Twitter",
-                                       "url": "//twitter.com",
-                                       "photo": "//abs.twimg.com/favicons/"
-                                                "twitter.ico"},
-                           "user": {"name": un, "url": f"//twitter.com/{un}",
-                                    "photo": user_photo}}
+            destination = {
+                "uid": f"//twitter.com/{un}",
+                "name": f"{un} on Twitter",
+                "service": {
+                    "name": "Twitter",
+                    "url": "//twitter.com",
+                    "photo": "//abs.twimg.com/favicons/" "twitter.ico",
+                },
+                "user": {"name": un, "url": f"//twitter.com/{un}", "photo": user_photo},
+            }
             tx.db.insert("syndication", destination=destination)
         if "github_username" in destinations:
             un = destinations.github_username
             # TODO token = destinations.github_token
             # TODO check the token
             user_photo = ""  # TODO doc.qS("img.avatar-user.width-full").src
-            destination = {"uid": f"//github.com/{un}",
-                           "name": f"{un} on GitHub",
-                           "service": {"name": "GitHub",
-                                       "url": "//github.com",
-                                       "photo": "//github.githubassets.com/"
-                                                "favicons/favicon.png"},
-                           "user": {"name": un, "url": f"//github.com/{un}",
-                                    "photo": user_photo}}
+            destination = {
+                "uid": f"//github.com/{un}",
+                "name": f"{un} on GitHub",
+                "service": {
+                    "name": "GitHub",
+                    "url": "//github.com",
+                    "photo": "//github.githubassets.com/" "favicons/favicon.png",
+                },
+                "user": {"name": un, "url": f"//github.com/{un}", "photo": user_photo},
+            }
             tx.db.insert("syndication", destination=destination)
 
 
@@ -912,19 +1010,23 @@ class MediaEndpoint:
                 filename = web.form("file").file.save(filename)
                 break
         if str(filename).endswith(".heic"):
-            sh.convert(filename, "-set", "filename:base", "%[basename]",
-                       f"{media_dir}/%[filename:base].jpg")
+            sh.convert(
+                filename,
+                "-set",
+                "filename:base",
+                "%[basename]",
+                f"{media_dir}/%[filename:base].jpg",
+            )
         sha256 = str(sh.sha256sum(filename)).split()[0]
         try:
-            tx.db.insert("media", mid=mid, sha256=sha256,
-                         size=filename.stat().st_size)
+            tx.db.insert("media", mid=mid, sha256=sha256, size=filename.stat().st_size)
         except tx.db.IntegrityError:
-            mid = tx.db.select("media", where="sha256 = ?",
-                               vals=[sha256])[0]["mid"]
+            mid = tx.db.select("media", where="sha256 = ?", vals=[sha256])[0]["mid"]
             filename.unlink()
         path = f"/pub/media/{mid}"
-        raise web.Created(f"File can be found at <a href={path}>{path}</a>",
-                          location=path)
+        raise web.Created(
+            f"File can be found at <a href={path}>{path}</a>", location=path
+        )
 
 
 @server.route(r"media/{filename}")
@@ -932,12 +1034,14 @@ class MediaFile:
     """."""
 
     def get(self):
-        content_types = {(".jpg", ".jpeg"): "image/jpg",
-                         ".heic": "image/heic",
-                         ".png": "image/png",
-                         ".mp3": "audio/mpeg",
-                         ".mov": "video/quicktime",
-                         ".mp4": "video/mp4"}
+        content_types = {
+            (".jpg", ".jpeg"): "image/jpg",
+            ".heic": "image/heic",
+            ".png": "image/png",
+            ".mp3": "audio/mpeg",
+            ".mov": "video/quicktime",
+            ".mp4": "video/mp4",
+        }
         for suffix, content_type in content_types.items():
             if self.filename.endswith(suffix):
                 web.header("Content-Type", content_type)
