@@ -4,8 +4,9 @@ from understory import web
 from understory.web import tx
 
 
-receiver = web.application("Webmention", mount_prefix="mentions",  # db=False,
-                           mention_id=r"\w+")
+receiver = web.application(
+    "Webmention", mount_prefix="mentions", mention_id=r"\w+"  # db=False,
+)
 templates = web.templates(__name__)
 
 
@@ -40,8 +41,9 @@ def receive(source, target) -> None:
     source_doc = tx.cache[source]
     source = source_doc.url.rstrip("/")
     mention = source_doc.mention(target).data  # TODO dict(..) inst .data
-    tx.db.update("mentions", what="data = ?", where="mention_id = ?",
-                 vals=[mention, mention_id])
+    tx.db.update(
+        "mentions", what="data = ?", where="mention_id = ?", vals=[mention, mention_id]
+    )
     return
 
     # XXX source_data = mf.parse(source_doc.text, url=source)
@@ -150,8 +152,7 @@ def receive(source, target) -> None:
 
 def store_mention(source, target):
     mention_id = web.nbrandom(9)
-    tx.db.insert("mentions", mention_id=mention_id, source=source,
-                 target=target)
+    tx.db.insert("mentions", mention_id=mention_id, source=source, target=target)
     return mention_id
 
 
@@ -167,9 +168,14 @@ def store_mention(source, target):
 
 def wrap(handler, app):
     """Ensure endpoint link in head of root document."""
-    tx.db.define(mentions="""received DATETIME NOT NULL DEFAULT
-                                 CURRENT_TIMESTAMP, mention_id TEXT,
-                             data JSON, source TEXT, target TEXT""")
+    tx.db.define(
+        "mentions",
+        received="DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP",
+        mention_id="TEXT",
+        data="JSON",
+        source="TEXT",
+        target="TEXT",
+    )
     # TODO sniff referer header for a mention
     # XXX print(f"REFERER: {tx.request.headers.get('Referer')}")
     yield
@@ -213,8 +219,9 @@ class Mention:
 
     def get(self):
         """Details of the webmention, with status information in mf2."""
-        mention = tx.db.select("mentions", where="mention_id = ?",
-                               vals=[self.mention_id])
+        mention = tx.db.select(
+            "mentions", where="mention_id = ?", vals=[self.mention_id]
+        )
         return templates.mention(mention)
 
     def post(self):
