@@ -17,9 +17,13 @@ from .clienterror import *  # noqa
 from .servererror import *  # noqa
 from .util import Status
 
-__all__ = ["Status"] + (informational.__all__ + success.__all__ +
-                        redirection.__all__ + clienterror.__all__ +
-                        servererror.__all__)
+__all__ = ["Status"] + (
+    informational.__all__
+    + success.__all__
+    + redirection.__all__
+    + clienterror.__all__
+    + servererror.__all__
+)
 
 
 def parse(response):
